package jp.veritrans.tercerog.sample.command.alipay;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AlipayAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.AlipayAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * AlipayAuthorizeCommand : Alipay決済(与信同時売上)サンプル
 */
public class AlipayAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        // ---------------------------------
        // テスト用リクエスト電文項目設定
        // ---------------------------------
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();

        // 金額(自動取得)
        // 通貨がCNYの場合は、100以上の値の指定が必須
        String amount = Custom.getAmount();

        // 通貨
        // "JPY"：日本円、"CNY"：中国元
        String currency = "JPY";

        // 支払種別
        // "0"：オンライン決済、"1"：バーコード決済(店舗スキャン型)、"2"：バーコード決済(消費者スキャン型)
        String payType = "0";

        // ユーザ識別コード
        // 決済種別がバーコード決済(店舗スキャン型)の場合は指定必須
        // 決済種別がオンライン決済、バーコード決済(消費者スキャン型)の場合は指定不可
        String identityCode = "1234567890";

        // 商品名
        String commodityName = "新製品";

        // 商品詳細
        // 決済種別がオンライン決済、バーコード決済(消費者スキャン型)の場合は指定任意
        // 決済種別がバーコード決済(店舗スキャン型)の場合は指定不可
        String commodityDescription = "新製品詳細";

        // 商品ID
        // 決済種別がバーコード決済(消費者スキャン型)、かつ、商品詳細を指定する場合は指定必須
        // 決済種別がオンライン決済、バーコード決済(店舗スキャン型)の場合は指定不可
        String commodityId = "newItemId";

        // 決済成功時URL
        // 決済種別がオンライン決済の場合は指定必須
        // 決済種別がバーコード決済(店舗スキャン型)、バーコード決済(消費者スキャン型)の場合は指定不可
        String successUrl = "http://localhost/web/alipay/AuthorizeResult";

        // 決済エラー時URL
        // 決済種別がオンライン決済の場合は指定必須
        // 決済種別がバーコード決済(店舗スキャン型)、バーコード決済(消費者スキャン型)の場合は指定不可
        String errorUrl = "http://localhost/web/alipay/AuthorizeResult";

        // レスポンスタイプ
        // 決済種別がバーコード決済(店舗スキャン型)の場合は指定可能
        // 決済種別がオンライン決済、バーコード決済(消費者スキャン型)の場合は指定不可
        // "0" : 取引確定時にレスポンスを返却する。
        // "1" : 即時にレスポンスを返却する。
        String responseType = "0";

        // ---------------------------------
        // リクエスト DTO 設定
        // ---------------------------------
        AlipayAuthorizeRequestDto reqDto = new AlipayAuthorizeRequestDto();
        // 取引IDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);
        // 通貨の設定
        reqDto.setCurrency(currency);
        // 決済種別の設定
        reqDto.setPayType(payType);
        // 商品名の設定
        reqDto.setCommodityName(commodityName);

        if ("0".equals(reqDto.getPayType())) {
            // 商品詳細の設定
            reqDto.setCommodityDescription(commodityDescription);
            // 決済成功時URLの設定
            reqDto.setSuccessUrl(successUrl);
            // 決済エラー時URLの設定
            reqDto.setErrorUrl(errorUrl);
        } else if ("1".equals(reqDto.getPayType())) {
            // ユーザ識別コードの設定
            reqDto.setIdentityCode(identityCode);
            // レスポンスタイプの設定
            reqDto.setResponseType(responseType);
        } else if ("2".equals(reqDto.getPayType())) {
            // 商品詳細の設定
            reqDto.setCommodityDescription(commodityDescription);
            // 商品IDの設定
            reqDto.setCommodityId(commodityId);
        }

        // ---------------------------------
        // 決済実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        AlipayAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (AlipayAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Alipay(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("Currency", currency);
            Custom.print("Pay Type", payType);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Order ID", resDto.getOrderId());
            if ("1".equals(reqDto.getPayType()) || "2".equals(reqDto.getPayType())) {
                Custom.print("Cust Txn", resDto.getCustTxn());
                Custom.print("Center Trade ID", resDto.getCenterTradeId());
            }
            if ("1".equals(reqDto.getPayType())) {
                Custom.print("Pay Time JP", resDto.getPayTimeJp());
                Custom.print("Pay Time CN", resDto.getPayTimeCn());
                Custom.print("Buyer Charged Amount Cny", resDto.getBuyerChargedAmountCny());
            } else if ("2".equals(reqDto.getPayType())) {
                Custom.print("QR Code", resDto.getQrCode());
                Custom.print("QR Code Img Url", resDto.getQrCodeImgUrl());
                Custom.print("QR Code Small Img Url", resDto.getQrCodeSmallImgUrl());
                Custom.print("QR Code Large Img Url", resDto.getQrCodeLargeImgUrl());
            }
        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
    }
}
