package jp.veritrans.tercerog.sample.command.alipay;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AlipayConfirmRequestDto;
import jp.veritrans.tercerog.mdk.dto.AlipayConfirmResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * AlipayConfirmCommand : Alipay決済(確認)サンプル
 */
public class AlipayConfirmCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        // ---------------------------------
        // テスト用リクエスト電文項目設定
        // ---------------------------------
        // 取引ID
        // 対象の取引IDを指定します
        String orderId = "change_order_here";
        // レスポンスタイプ
        // "0" : 取引確定時にレスポンスを返却する。
        // "1" : 即時にレスポンスを返却する。
        String responseType = "0";

        // ---------------------------------
        // リクエスト DTO 設定
        // ---------------------------------
        AlipayConfirmRequestDto reqDto = new AlipayConfirmRequestDto();
        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // レスポンスタイプの設定
        reqDto.setResponseType(responseType);

        // ---------------------------------
        // 決済実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        AlipayConfirmResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (AlipayConfirmResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Alipay(Confirm) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderId);
            Custom.print("Response Type", responseType);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Order ID", resDto.getOrderId());
            Custom.print("Cust Txn", resDto.getCustTxn());
            Custom.print("Center Trade ID", resDto.getCenterTradeId());
            Custom.print("Pay Time JP", resDto.getPayTimeJp());
            Custom.print("Pay Time CN", resDto.getPayTimeCn());
            Custom.print("Buyer Charged Amount Cny", resDto.getBuyerChargedAmountCny());
        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
    }
}
