package jp.veritrans.tercerog.sample.command.amazonpay;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AmazonpayAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.AmazonpayAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * AmazonpayAuthorizeCommand : Amazon Pay(与信)サンプル
 */
public class AmazonpayAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 支払金額(自動取得)
        String amount = "10";
        // 与信同時売上
        String withCapture = "false";
        // 配送先表示抑制フラグ
        String suppressShippingAddressView = "false";
        // 注文説明
        String noteToBuyer = "テスト商品";
        // 完了時URL
        String successUrl = "https://sample.com";
        // キャンセル時URL
        String cancelUrl = "https://sample.com";
        // エラー時URL
        String errorUrl = "https://sample.com";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        AmazonpayAuthorizeRequestDto reqDto = new AmazonpayAuthorizeRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);
        // 与信同時売上の設定
        reqDto.setWithCapture(withCapture);
        // 配送先表示抑制フラグの設定
        reqDto.setSuppressShippingAddressView(suppressShippingAddressView);
        // 注文説明の設定
        reqDto.setNoteToBuyer(noteToBuyer);
        // 完了時URLの設定
        reqDto.setSuccessUrl(successUrl);
        // キャンセル時URLの設定
        reqDto.setCancelUrl(cancelUrl);
        // エラー時URLの設定
        reqDto.setErrorUrl(errorUrl);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        AmazonpayAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (AmazonpayAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Amazon Pay(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("WithCapture", withCapture);
            Custom.print("Suppress Shipping Address View", suppressShippingAddressView);
            Custom.print("Note To Buyer", noteToBuyer);
            Custom.print("Success Url", successUrl);
            Custom.print("Cancel Url", cancelUrl);
            Custom.print("Error Url", errorUrl);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Response Contents", resDto.getResponseContents());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
