package jp.veritrans.tercerog.sample.command.bank;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.BankAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.BankAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;


/**
 * BankAuthorizeCommand : 銀行決済(与信)サンプル
 */
public class BankAuthorizeCommand {

	/**
	 * コマンドテスト用メインメソッド
	 */
	public static void main(String[] args) {

		//---------------------------------
		// テスト用リクエスト電文項目設定  
		//---------------------------------
		/**
		 * 決済方式
		 * 
		 * ATM決済 : atm
		 * ネットバンク決済銀行リンク方式（PC） : netbank-pc
		 * ネットバンク決済銀行リンク方式（docomo） : netbank-docomo
		 * ネットバンク決済銀行リンク方式（SoftBank） : netbank-softbank
		 * ネットバンク決済銀行リンク方式（au） : netbank-au
		 * (※ご注意： ネットバンク決済の部分は、コマンドラインサンプルで
		 *    画面のリンクはできないため、参考としてここに記述しております。)
		 */
		String serviceOptionType = "atm";

		/**
		 * 取引ID(自動生成)
		 */
	    String orderID = Custom.getOrderID();

	    /**
	     * 支払金額(自動取得)
	     */
	    String amount = Custom.getAmount();

	    /**
	     * 顧客名1
	     */
	     String clientName1 = "顧客　氏名";
	    
	    /**
	     * 顧客名カナ1
	     */
	     String clientKana1 = "コキャクシメイカナ";
	     
	    /**
	     * 郵便番号1
	     */
	    String postalCode1 = "123";
	      
	    /**
	     * 郵便番号2
	     */
	     String postalCode2 = "4567";
	    
	    /**
	     * 住所
	     */
	     String address1 = "東京都港区１－６－１";

	    /**
	     * 電話番号
	     */ 
	     String telephoneNumber = "0123456789";
	     
	    /**
	     * 支払期限(YYYYMMDD)
	     * サンプルとして10日後の日付を設定
	     */
	     String paymentLimit = Custom.getPaymentLimit("yyyyMMdd", 10);
	     
	    /**
	     * 成約日
	     */
	    String agreementDate = Custom.getSystemDate();
	     
	    /**
	     * 請求内容
	     */
	    String contents = "表示インフォメーション";
	    
	    /**
	     * 請求内容カナ
	     */
	    String contentsKana = "ヒョウジインフォメーションカナ";
	    
		//---------------------------------
		// リクエスト DTO 設定  
		//---------------------------------
	    BankAuthorizeRequestDto reqDto = new BankAuthorizeRequestDto();
	    // 決済方式の設定
	    reqDto.setServiceOptionType(serviceOptionType);
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);
        // 顧客名１の設定
        reqDto.setName1(clientName1);
        // 顧客名カナ１の設定
        reqDto.setKana1(clientKana1);
        // 郵便番号１の設定
        reqDto.setPost1(postalCode1);
        // 郵便番号２の設定
        reqDto.setPost2(postalCode2);
        // 住所の設定
        reqDto.setAddress1(address1);
        // 電話番号の設定
        reqDto.setTelNo(telephoneNumber);
        // 支払期限の設定
        reqDto.setPayLimit(paymentLimit);
        // 成約の設定
        reqDto.setAgreementDate(agreementDate);
        // 請求内容の設定
        reqDto.setContents(contents);
        // 請求内容カナの設定
        reqDto.setContentsKana(contentsKana);
        
		//---------------------------------
		// 決済実行と結果表示  
		//---------------------------------
        ITransaction tran = null;
        BankAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (BankAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Bank(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Service Option Type", serviceOptionType);
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("Client Name1", clientName1);
            Custom.print("Client Kana1", clientKana1);
            Custom.print("Postal Code1", postalCode1);
            Custom.print("Postal Code2", postalCode2);
            Custom.print("Address1", address1);
            Custom.print("Telephone Number", telephoneNumber);
            Custom.print("Payment Limit", paymentLimit);
            Custom.print("Agreement Date", agreementDate);
            Custom.print("Contents", contents);
            Custom.print("Contents Kana", contentsKana);
            
            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Shuno Kikan No", resDto.getShunoKikanNo());
            Custom.print("Customer No", resDto.getCustomerNo());
            Custom.print("Confirm No", resDto.getConfirmNo());
            Custom.print("URL(Only in Link type)", resDto.getUrl());
            Custom.print("View(Only in Link type)", resDto.getView());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
	
	}

}
