package jp.veritrans.tercerog.sample.command.carrier;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CarrierTerminateRequestDto;
import jp.veritrans.tercerog.mdk.dto.CarrierTerminateResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * CarrierTerminateCommand : キャリア決済(継続終了)サンプル
 */
public class CarrierTerminateCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // キャリア
        String carrier = "docomo";
        // 取引ID(与信時に利用したものを設定してください)
        String orderID = "1234567890";
        // 強制解約
        String force = "true";
        // 端末種別
        String terminalKind = "0";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        CarrierTerminateRequestDto reqDto = new CarrierTerminateRequestDto();

        // キャリア
        reqDto.setServiceOptionType(carrier);
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 強制解約
        reqDto.setForce(force);
        // 端末種別
        reqDto.setTerminalKind(terminalKind);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        CarrierTerminateResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (CarrierTerminateResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Carrier(Terminate) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Force", String.valueOf(force));
            Custom.print("TerminalKind", terminalKind);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("TerminateDatetime", resDto.getTerminateDatetime());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
            Custom.print("Exception Message" + "");
            ex.printStackTrace();
        }

    }

}
