package jp.veritrans.tercerog.sample.command.cvs;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CvsAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CvsAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;


/**
 * CvsAuthorizeCommand : コンビニ決済(与信)サンプル
 */
public class CvsAuthorizeCommand {

	/**
	 * コマンドテスト用メインメソッド
	 */
	public static void main(String[] args) {

		//---------------------------------
		// テスト用リクエスト電文項目設定  
		//---------------------------------
		// コンビニエンスストアの分類を指定
		//   "sej" - セブンイレブン
		//   "econ" - イーコンテキスト(ファミリーマート、ローソン、セイコーマート等)
		//   "other" - ウェルネット(サークルKサンクス等)
		String serviceOptionType = "econ";
	    // 取引ID(自動生成)
	    String orderID = Custom.getOrderID();
	    // 支払金額(自動取得)
	    String amount = Custom.getAmount();
	    // 氏名１（姓）
	    String lastName = "顧客姓";
	    // 氏名２（姓）
	    String firstName = "顧客名";
	    // 電話番号
	    //   注）ダミーリクエストフラグが1のとき使用可能な番号体系はご利用ガイドを参考してください。
	    String telNumber = "05-1234-5678";
	    // 支払期限(YYYY/MM/DD)
	    //   サンプルとして10日後の日付を設定
	    String paymentLimit = Custom.getPaymentLimit("yyyy/MM/dd", 10);
	    
		//---------------------------------
		// リクエスト DTO 設定  
		//---------------------------------
	    CvsAuthorizeRequestDto reqDto = new CvsAuthorizeRequestDto();
	    // コンビニエンスストアの分類設定
	    reqDto.setServiceOptionType(serviceOptionType);
	    // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);
        // 氏名１の設定
        reqDto.setName1(lastName);
        // 氏名２の設定
        reqDto.setName2(firstName);
        // 電話番号の設定
        reqDto.setTelNo(telNumber);
        // 支払期限の設定
        reqDto.setPayLimit(paymentLimit);
        // 支払区分の設定('0'で固定)
        reqDto.setPaymentType("0");
		
		//---------------------------------
		// 決済実行と結果表示  
		//---------------------------------
        ITransaction tran = null;
        CvsAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (CvsAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Cvs(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("CVS Type", serviceOptionType);
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("(Name1)Last Name", lastName);
            Custom.print("(Name2)First Name", firstName);
            Custom.print("Telephone No", telNumber);
            Custom.print("Payment Limit", paymentLimit);
            
            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Receipt No", resDto.getReceiptNo());
            Custom.print("Haraikomi URL", resDto.getHaraikomiUrl());
        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
	
	}

}
