package jp.veritrans.tercerog.sample.command.em;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.EmCancelRequestDto;
import jp.veritrans.tercerog.mdk.dto.EmCancelResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * EmCancelCommand : 電子マネー決済(キャンセル)サンプル
 */
public class EmCancelCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        // ---------------------------------
        // テスト用リクエスト電文項目設定
        // ---------------------------------
        // [決済方式]
        // モバイルSuicaメール決済 : suica-mobile-mail
        // モバイルSuicaアプリ決済 : suica-mobile-app
        // Suicaインターネット決済メール連携 : suica-pc-mail
        // Suicaインターネット決済アプリ連携 : suica-pc-app
        // nanaco決済 : tcc-redirect
        String serviceOptionType = "suica-mobile-app";
        // 取引ID
        String orderID = "";
        // オーダー種別
        String orderKind = "authorize";

        // ---------------------------------
        // リクエスト DTO 設定
        // ---------------------------------
        EmCancelRequestDto reqDto = new EmCancelRequestDto();
        // 決済方式の設定
        reqDto.setServiceOptionType(serviceOptionType);
        // 取引IDの設定
        reqDto.setOrderId(orderID);

        if (serviceOptionType.startsWith("suica")) {
            // オーダー種別の設定
            reqDto.setOrderKind(orderKind);
        }

        // ---------------------------------
        // 決済実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        EmCancelResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (EmCancelResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Em(Cancel) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("ServiceOptionType", serviceOptionType);
            Custom.print("Order ID", orderID);
            Custom.print("Order Kind", orderKind);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Order ID", resDto.getOrderId());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
    }
}
