package jp.veritrans.tercerog.sample.command.paynowid;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.RecurringAddRequestDto;
import jp.veritrans.tercerog.mdk.dto.RecurringAddResponseDto;
import jp.veritrans.tercerog.mdk.dto.PayNowIdResponse;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * PayNowIdRecurringMasterAddCommand : PayNowId(継続課金登録)処理用サーブレット
 */
public class PayNowIdRecurringAddCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        // ---------------------------------
        // テスト用リクエスト電文項目設定
        // ---------------------------------
        // 会員ID
        String accountId = "TestAccountId";
        // 課金グループID
        String groupId = "merchant4";
        // 課金開始日
        String startDate = "20130930";
        // 課金終了日
        String endDate = "20140930";
        // 都度／初回課金金額
        String oneTimeAmount = "10";
        // 継続課金金額
        String amount = "10";
        // カード番号
        // String cardNumber = "4111-1111-1111-1111";
        // カード有効期限
        // String cardExpire = "12/16";
        // トークン
        String token = "0a812412-682c-4dad-8a5d-720caf23bca0";

        // ---------------------------------
        // リクエスト DTO 設定
        // ---------------------------------
        RecurringAddRequestDto reqDto = new RecurringAddRequestDto();
        // 会員IDの設定
        reqDto.setAccountId(accountId);
        // 課金グループIDの設定
        reqDto.setGroupId(groupId);
        // 課金開始日の設定
        reqDto.setStartDate(startDate);
        // 課金終了日の設定
        reqDto.setEndDate(endDate);
        // 都度／初回課金金額の設定
        reqDto.setOneTimeAmount(oneTimeAmount);
        // 継続課金金額の設定
        reqDto.setAmount(amount);
        // カード番号の設定
        // reqDto.setCardNumber(cardNumber);
        // 有効期限の設定
        // reqDto.setCardExpire(cardExpire);
        // トークンの設定
        reqDto.setToken(token);

        // ---------------------------------
        // 処理実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        RecurringAddResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (RecurringAddResponseDto) tran.execute();
            PayNowIdResponse payNowIdRes = resDto.getPayNowIdResponse();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- PayNowId(RecurringAdd) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("ServiceType", resDto.getServiceType());
            Custom.print("Account ID", accountId);
            Custom.print("Group ID", groupId);
            Custom.print("Start Date", startDate);
            Custom.print("End Date", endDate);
            Custom.print("OneTimeAmount", oneTimeAmount);
            Custom.print("Amount", amount);
            // Custom.print("Card Number", cardNumber);
            // Custom.print("Card Expired Date", cardExpire);
            Custom.print("Token", token);

            Custom.print("<< RESPONSE >>");
            Custom.print("PayNowId Status", (payNowIdRes != null) ? payNowIdRes.getStatus() : "I do not know status because of PayNowIdResponse is null.");
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("PayNowId ProcId", (payNowIdRes != null) ? payNowIdRes.getProcessId() : "I do not know ProcessId because of PayNowIdResponse is null.");

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message " + ex.getMessage());
        }

    }
}
