package jp.veritrans.tercerog.sample.command.paynowid;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.RecurringDeleteRequestDto;
import jp.veritrans.tercerog.mdk.dto.RecurringDeleteResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * PayNowIdRecurringMasterDeleteCommand : PayNowId(継続課金削除)処理用サーブレット
 */
public class PayNowIdRecurringDeleteCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        // ---------------------------------
        // テスト用リクエスト電文項目設定
        // ---------------------------------
        // 会員ID
        String accountId = "TestAccountId";
        // 課金グループID
        String groupId = "merchant4";
        // 課金終了日
        String endDate = "20140930";
        // 課金自動終了フラグ
        String finalCharge = "0";

        // ---------------------------------
        // リクエスト DTO 設定
        // ---------------------------------
        RecurringDeleteRequestDto reqDto = new RecurringDeleteRequestDto();

        // 会員IDの設定
        reqDto.setAccountId(accountId);
        // 課金グループIDの設定
        reqDto.setGroupId(groupId);
        // 課金終了日の設定
        reqDto.setEndDate(endDate);
        // 課金自動終了フラグの設定
        reqDto.setFinalCharge(finalCharge);

        // ---------------------------------
        // 処理実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        RecurringDeleteResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (RecurringDeleteResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- PayNowId(RecurringDelete) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("ServiceType", resDto.getServiceType());
            Custom.print("Account ID", accountId);
            Custom.print("Group ID", groupId);
            Custom.print("End Date", endDate);
            Custom.print("FinalCharge", finalCharge);

            Custom.print("<< RESPONSE >>");
            Custom.print("PayNowId Status", resDto.getPayNowIdResponse().getStatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("PayNowId ProcId", resDto.getPayNowIdResponse().getProcessId());
            
        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message " + ex.getMessage());
        }
    }
}
