package jp.veritrans.tercerog.sample.command.paypay;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.PaypayCancelRequestDto;
import jp.veritrans.tercerog.mdk.dto.PaypayCancelResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * PaypayCancelCommand : paypayオンライン決済(取消)サンプル
 */
public class PaypayOnlineCancelCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(決済申込時に利用したものを設定してください)
        String orderID = "1234567890";
        // サービスオプションタイプ：オンライン
        String serviceOptionType = MdkServiceConstants.PAYPAY_ONLINE;

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        PaypayCancelRequestDto reqDto = new PaypayCancelRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 決済方式の設定
        reqDto.setServiceOptionType(serviceOptionType);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        PaypayCancelResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (PaypayCancelResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- paypay(Cancel) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
