package jp.veritrans.tercerog.sample.command.rakuten;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.RakutenCaptureRequestDto;
import jp.veritrans.tercerog.mdk.dto.RakutenCaptureResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * RakutenCaptureCommand : 楽天ID決済(売上)サンプル
 */
public class RakutenCaptureCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(与信時に利用したものを設定してください)
        String orderID = "1234567890";
        
        // 売上金額
        String amount = "100";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        RakutenCaptureRequestDto reqDto = new RakutenCaptureRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        reqDto.setAmount(amount);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        RakutenCaptureResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (RakutenCaptureResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Rakuten(Capture) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Capture Req Datetime", resDto.getCaptureReqDatetime());
            Custom.print("Transaction Datetime", resDto.getTransactionDatetime());
            Custom.print("Rakuten Order Id", resDto.getRakutenOrderId());
            Custom.print("Gateway Order Id", resDto.getGatewayOrderId());
            Custom.print("Used Point", resDto.getUsedPoint());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
