package jp.veritrans.tercerog.sample.command.rakuten;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.RakutenReAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.RakutenReAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * RakutenReAuthorizeCommand : 楽天ID決済(再与信)サンプル
 */

public class RakutenReAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(与信時に利用したものを設定してください)
        String orderID = "1234567890";
        // 元取引ID(随時決済の決済申込時に指定した取引IDを設定してください)
        String originalOrderId = "";
        // 与信方法(同時売上実施の有無)
        String withCapture = "false";
        // 再与信金額
        String amount = "100";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        RakutenReAuthorizeRequestDto reqDto = new RakutenReAuthorizeRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 元取引IDの設定
        reqDto.setOriginalOrderId(originalOrderId);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // 商品番号
        reqDto.setItemId("123456");
        // 商品名
        reqDto.setItemName("sample商品");

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        RakutenReAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (RakutenReAuthorizeResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Rakuten(ReAuthorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Original Order Id", originalOrderId);
            Custom.print("WithCapture", withCapture);
            Custom.print("Amount", amount);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Original Order Id", originalOrderId);
            Custom.print("Rakuten Order Id", resDto.getRakutenOrderId());
            Custom.print("Gateway Order Id", resDto.getGatewayOrderId());
            Custom.print("Rakuten Consent Order Id", resDto.getRakutenConsentOrderId());
            Custom.print("Customer Id", resDto.getCustomerId());
            Custom.print("Used Point", resDto.getUsedPoint());
            Custom.print("Card Brand", resDto.getCardBrand());
            Custom.print("Card Last4", resDto.getCardLast4());
            Custom.print("Card Installments", resDto.getCardInstallments());
            Custom.print("Card Cvc", resDto.getCardCvc());
            Custom.print("Card 3ds", resDto.getCard3ds());
            Custom.print("Transaction Datetime", resDto.getTransactionDatetime());
            Custom.print("Cancel Expiration Time", resDto.getCancelExpirationTime());
            Custom.print("Capture Expiration Time", resDto.getCaptureExpirationTime());
            Custom.print("Update Expiration Time", resDto.getUpdateExpirationTime());
            Custom.print("Extend Auth Expiration Time", resDto.getExtendAuthExpirationTime());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}