package jp.veritrans.tercerog.sample.command.upop;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.UpopRefundRequestDto;
import jp.veritrans.tercerog.mdk.dto.UpopRefundResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * UpopRefundCommand : 銀聯ネット決済(UPOP)(返金)サンプル
 */
public class UpopRefundCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        // ---------------------------------
        // テスト用リクエスト電文項目設定
        // ---------------------------------
        // 取引ID(売上時に利用したものを設定してください)
        String orderID = "1234567890";
        // 金額
        String amount = "10";

        // ---------------------------------
        // リクエスト DTO 設定
        // ---------------------------------
        UpopRefundRequestDto reqDto = new UpopRefundRequestDto();
        // 取引IDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);

        // ---------------------------------
        // 決済実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        UpopRefundResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (UpopRefundResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- UPOP(Refund) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Txn Datetime Jp", resDto.getTxnDatetimeJp());
            Custom.print("Txn Datetime Cn", resDto.getTxnDatetimeCn());
            Custom.print("Captured Amount", resDto.getCapturedAmount());
            Custom.print("Remaining Amount", resDto.getRemainingAmount());
            Custom.print("Settle Amount", resDto.getSettleAmount());
            Custom.print("Settle Date", resDto.getSettleDate());
            Custom.print("Settle Currency", resDto.getSettleCurrency());
            Custom.print("Settle Rate", resDto.getSettleRate());
            Custom.print("Upop Order Id", resDto.getUpopOrderId());
        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
    }
}
