package jp.veritrans.tercerog.sample.command.virtualacc;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.VirtualaccAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.VirtualaccAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * VirtualaccAuthorizeCommand : 銀行振込決済(決済)サンプル
 */
public class VirtualaccAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 支払金額(自動取得)
        String amount = Custom.getAmount();
        // 口座振込人名
        String entryTransferName = "テストタロウ";
        // 口座振込番号
        String entryTransferNumber = "００００１";
        // 振込期限
        String transferExpiredDate = "";

        // 口座管理方式
        // 実口座 : VACC_ACCOUNT_MANAGE_TYPE_REAL
        // バーチャル口座 : VACC_ACCOUNT_MANAGE_TYPE_VIRTUAL
        String accountManageType = MdkServiceConstants.VACC_ACCOUNT_MANAGE_TYPE_REAL;

        // 支店コード・口座番号は口座管理号式がバーチャル口座の場合のみ設定
        // 支店コード
        String branchCode = "";
        // 口座番号
        String accountNumber = "";

        // サービスオプションタイプ
        // りそな : MdkServiceConstants.VACC_RESONA
        String serviceOptionType = MdkServiceConstants.VACC_RESONA;

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        VirtualaccAuthorizeRequestDto reqDto = new VirtualaccAuthorizeRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);
        // 口座振込人名の設定
        reqDto.setEntryTransferName(entryTransferName);
        // 口座振込番号の設定
        reqDto.setEntryTransferNumber(entryTransferNumber);
        // 振込期限の設定
        reqDto.setTransferExpiredDate(transferExpiredDate);
        // 口座管理方式の設定
        reqDto.setAccountManageType(accountManageType);
        // 支店コードの設定
        reqDto.setBranchCode(branchCode);
        // 口座番号の設定
        reqDto.setAccountNumber(accountNumber);
        // サービスオプションタイプの設定
        reqDto.setServiceOptionType(serviceOptionType);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        VirtualaccAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (VirtualaccAuthorizeResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Virtualacc(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("Entry Transfer Name", entryTransferName);
            Custom.print("Entry Transfer Number", entryTransferNumber);
            Custom.print("Transfer Expired Date", transferExpiredDate);
            Custom.print("Account Manage Type", accountManageType);
            Custom.print("Branch Code", branchCode);
            Custom.print("Account Number", accountNumber);

            Custom.print("<< RESPONSE >>");
            Custom.print("Order ID", resDto.getOrderId());
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Transfer Name", resDto.getTransferName());
            Custom.print("Bank Name", resDto.getBankName());
            Custom.print("Bank Code", resDto.getBankCode());
            Custom.print("Branch Name", resDto.getBranchName());
            Custom.print("Branch Code", resDto.getBranchCode());
            Custom.print("Account Type", resDto.getAccountType());
            Custom.print("Account Number", resDto.getAccountNumber());
            Custom.print("Account Name", resDto.getAccountName());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }
}
