package jp.veritrans.tercerog.sample.command.virtualacc;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.VirtualaccDepositEntryRequestDto;
import jp.veritrans.tercerog.mdk.dto.VirtualaccDepositEntryResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * VirtualaccDepositEntryCommand : 銀行振込決済(入金)サンプル
 */
public class VirtualaccDepositEntryCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(申込請求時に利用したものを設定してください)
        String orderID = "";
        // 入金金額
        String amount = "";
        // 入金日の設定(YYYYMMDD)
        String depositDate = "";
        // 振込人名の設定
        String transferName = "テストフリコミタロウ";
        // 消込フラグの設定
        // 消込しない : MdkServiceConstants.VACC_WITH_RECONCILE_NOT or 未指定
        // 消込(強制) : MdkServiceConstants.VACC_WITH_RECONCILE_FORCE
        // 消込(自動) : MdkServiceConstants.VACC_WITH_RECONCILE_AUTO
        String withReconcile = "";
        // 登録方法の設定
        // 手動 : MdkServiceConstants.VACC_REGISTRATION_METHOD_MANUAL or 未指定
        // 自動 : MdkServiceConstants.VACC_REGISTRATION_METHOD_AUTO
        String registrationMethod = "";

        // サービスオプションタイプ
        // りそな : MdkServiceConstants.VACC_RESONA
        String serviceOptionType = MdkServiceConstants.VACC_RESONA;

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        VirtualaccDepositEntryRequestDto reqDto = new VirtualaccDepositEntryRequestDto();
        // 取引IDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);
        // 振込人名の設定
        reqDto.setTransferName(transferName);
        // 消込フラグの設定
        reqDto.setWithReconcile(withReconcile);
        // 登録方法の設定
        reqDto.setRegistrationMethod(registrationMethod);
        // 入金日の設定
        reqDto.setDepositDate(depositDate);
        // サービスオプションタイプの設定
        reqDto.setServiceOptionType(serviceOptionType);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        VirtualaccDepositEntryResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (VirtualaccDepositEntryResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Virtualacc(DepositEntry) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("Transfer Name", transferName);
            Custom.print("With Reconcile", withReconcile);
            Custom.print("Registration Method", registrationMethod);
            Custom.print("Deposit Date", depositDate);

            Custom.print("<< RESPONSE >>");
            Custom.print("Order ID", resDto.getOrderId());
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Total Deposit Amount", resDto.getTotalDepositAmount());
            Custom.print("Deposit ID", resDto.getDepositId());
            Custom.print("Order Status", resDto.getOrderStatus());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }
}
