package jp.veritrans.tercerog.sample.web;

import java.io.IOException;
import java.net.URLEncoder;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;

/**
 * 支払い方法選択画面のサーブレット。<br>
 * 次の画面への遷移を制御する。
 */
public class PaymentMethodSelect extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /** 支払方法選択で【クレジットカード（本人認証無し）】が選択された事を示す定数 */
    private static final String CARD_CODE = "card";

    /** 支払方法選択で【電子マネー】が選択された事を示す定数 */
    private static final String E_MONEY_CODE = "em";

    /** 支払方法選択で【コンビニエンスストア】が選択された事を示す定数 */
    private static final String CONVINIENCE_CODE = "cvs";

    /** 支払方法選択で【銀行】が選択された事を示す定数 */
    private static final String BANK_CODE = "bank";

    /** 支払方法選択で【PayPal】が選択された事を示す定数 */
    private static final String PAYPAL_CODE = "paypal";

    /** 支払方法選択で【クレジットカード（3D認証有り）】が選択された事を示す定数 */
    private static final String MPI_CODE = "mpi";

    /** 支払方法選択で【永久不滅ポイント】が選択された事を示す定数 */
    private static final String SAISON_CODE = "saison";

    /** 支払方法選択で【銀聯ネット決済(UPOP)】が選択された事を示す定数 */
    private static final String UPOP_CODE = "upop";

    /** 支払方法選択で【Alipay】が選択された事を示す定数 */
    private static final String ALIPAY_CODE = "alipay";

    /** 支払方法選択で【キャリア】が選択された事を示す定数 */
    private static final String CARRIER_CODE = "carrier";

    /** 支払方法選択で【ショッピングクレジット】が選択された事を示す定数 */
    private static final String ORICOSC_CODE = "oricosc";

    /** 支払方法選択で【楽天】が選択された事を示す定数 */
    private static final String RAKUTEN_CODE = "rakuten";

    /** 支払い方法選択で【リクルート】が選択されたことを示す定数 */
    private static final String RECRUIT_CODE = "recruit";

    /** 支払い方法選択で【LINE Pay】が選択されたことを示す定数 */
    private static final String LINEPAY_CODE = "linepay";

    /** 支払い方法選択で【MasterPass】が選択されたことを示す定数 */
    private static final String MASTERPASS_CODE = "masterpass";

    /** 支払い方法選択で【銀行振込決済】が選択されたことを示す定数 */
    private static final String VIRTUALACC_CODE = "virtualacc";

    /** 支払い方法選択で【paypay】が選択されたことを示す定数 */
    private static final String PAYPAY_CODE = "paypay";

    /** 支払い方法選択で【Amazon Pay】が選択されたことを示す定数 */
    private static final String AMAZONPAY_CODE = "amazonpay";

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        try {
            String selectMethod = request.getParameter("method"); // 次画面の選択
            String price = request.getParameter("price"); // 次の画面へ引き継ぐ金額

            // 価格を次画面へ渡す
            request.setAttribute("price", price);

            // 次画面への遷移
            if (CARD_CODE.equals(selectMethod)) {
                // クレジットカード（本人認証無し）
                response.sendRedirect("./card/Authorize?price=" + price);

            } else if (MPI_CODE.equals(selectMethod)) {
                // クレジットカード（3D認証有り）
                response.sendRedirect("./mpi/Authorize?price=" + price);

            } else if (E_MONEY_CODE.equals(selectMethod)) {
                // 電子マネー
                response.sendRedirect("./em/Menu?price=" + price);

            } else if (CONVINIENCE_CODE.equals(selectMethod)) {
                // コンビニエンスストア
                response.sendRedirect("./cvs/Authorize?price=" + price);

            } else if (BANK_CODE.equals(selectMethod)) {
                // 銀行
                response.sendRedirect("./bank/Authorize?price=" + price);

            } else if (PAYPAL_CODE.equals(selectMethod)) {
                // PayPal
                response.sendRedirect("./paypal/Authorize?price=" + price);

            } else if (SAISON_CODE.equals(selectMethod)) {
                // 永久不滅ポイント
                response.sendRedirect("./saison/Authorize?price=" + price);

            } else if (UPOP_CODE.equals(selectMethod)) {
                // 銀聯ネット決済(UPOP)
                response.sendRedirect("./upop/Authorize?price=" + price);

            } else if (ALIPAY_CODE.equals(selectMethod)) {
                // Alipay
                response.sendRedirect("./alipay/Authorize?price=" + price);

            } else if (CARRIER_CODE.equals(selectMethod)) {
                // キャリア決済(CARRIER)
                response.sendRedirect("./carrier/Menu?price=" + price);

            } else if (ORICOSC_CODE.equals(selectMethod)) {
                // ショッピングクレジット
                String item1_quantity = "1";
                String item1_name = URLEncoder.encode("テスト商品１", "UTF-8");
                price = "500";
                response.sendRedirect("./oricosc/Authorize?item1_price=" + price //
                        + "&item1_quantity=" + item1_quantity + "&item1_name=" + item1_name);

            } else if (RAKUTEN_CODE.equals(selectMethod)) {
                // 楽天
                String itemName = URLEncoder.encode("テスト商品", "UTF-8");
                price = "100";
                response.sendRedirect("./rakuten/Authorize?price=" + price
                        + "&itemName=" + itemName);

            } else if (RECRUIT_CODE.equals(selectMethod)) {
                // リクルート
                String itemName = URLEncoder.encode("テスト商品", "UTF-8");
                response.sendRedirect("./recruit/Authorize?price=" + price
                        + "&itemName=" + itemName);

            } else if (LINEPAY_CODE.equals(selectMethod)) {
                // LINE Pay
                String itemName = URLEncoder.encode("テスト商品", "UTF-8");
                response.sendRedirect("./linepay/Authorize?price=" + price
                        + "&itemName=" + itemName);

            } else if (MASTERPASS_CODE.equals(selectMethod)) {
                // MasterPass
                String quantity1 = "1";
                String itemName = URLEncoder.encode("テスト商品", "UTF-8");
                response.sendRedirect("./masterpass/Login?quantity1=" + quantity1
                        + "&value1=" + price
                        + "&description1=" + itemName);
            } else if (VIRTUALACC_CODE.equals(selectMethod)) {
                // 銀行振込
                String accountManageType = MdkServiceConstants.VACC_ACCOUNT_MANAGE_TYPE_REAL;
                String entryTransferNumber = URLEncoder.encode("００００１", "UTF-8");
                String entryTransferName = URLEncoder.encode("テストタロウ", "UTF-8");
                response.sendRedirect("./virtualacc/Authorize?price=" + price
                        + "&accountManageType=" + accountManageType
                        + "&entryTransferNumber=" + entryTransferNumber
                        + "&entryTransferName=" + entryTransferName);
            } else if (PAYPAY_CODE.equals(selectMethod)) {
                // paypay
                response.sendRedirect("./paypay/Menu?price=" + price);
            } else if (AMAZONPAY_CODE.equals(selectMethod)) {
                // Amazon Pay
                response.sendRedirect("./amazonpay/Authorize?price=" + price);
            } else {
                // 未選択、不明な値の場合は元の画面に戻る
                forward(request, response, "./PaymentMethodSelect.jsp");
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
