package jp.veritrans.tercerog.sample.web.alipay;

import java.io.IOException;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AlipayAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.AlipayAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * Alipay決済処理クラス。
 */
public class AuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    @Override
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 外貨の取得
        String currency = request.getParameter("currency");
        // 決済完了時URLの取得
        String successUrl = request.getParameter("successUrl");
        // 決済エラー時URLの取得
        String errorUrl = request.getParameter("errorUrl");
        // 商品IDの取得
        String commodityId = request.getParameter("commodityId");
        // 商品名の取得
        String commodityName = request.getParameter("commodityName");
        // 商品詳細の取得
        String commodityDescription = request.getParameter("commodityDescription");
        // ユーザ識別コード
        String identityCode = request.getParameter("identityCode");
        // 決済種別
        String payType = request.getParameter("payType");
        // レスポンスタイプ
        String responseType = request.getParameter("responseType");

        Locale objLcl = request.getLocale();
        ResourceBundle rb = ResourceBundle.getBundle("3GPSMDK", objLcl);
        String dummyRequest = rb.getString("DUMMY_REQUEST");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        } else if (isNull(currency)) {
            warning = "<font color='#ff0000'><b>必須項目：通貨が指定されていません</b></font>";
        } else if ("1".equals(dummyRequest) && "CNY".equals(currency) && Long.parseLong(amount) < 100) {
            warning = "<font color='#ff0000'><b>不正項目：金額には100以上の値を指定してください</b></font>";
        } else if (isNull(successUrl) && "0".equals(payType)) {
            warning = "<font color='#ff0000'><b>必須項目：決済完了時URLが指定されていません</b></font>";
        } else if (isNull(errorUrl) && "0".equals(payType)) {
            warning = "<font color='#ff0000'><b>必須項目：決済エラー時URLが指定されていません</b></font>";
        } else if (isNull(commodityName)) {
            warning = "<font color='#ff0000'><b>必須項目：商品名が指定されていません</b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Authorize.jsp");
            return;
        }

        AlipayAuthorizeRequestDto reqDto = new AlipayAuthorizeRequestDto();

        reqDto.setOrderId(orderId);
        reqDto.setAmount(amount);
        reqDto.setCurrency(currency);
        reqDto.setSuccessUrl(successUrl);
        reqDto.setErrorUrl(errorUrl);
        reqDto.setCommodityId(commodityId);
        reqDto.setCommodityName(commodityName);
        reqDto.setCommodityDescription(commodityDescription);
        reqDto.setIdentityCode(identityCode);
        reqDto.setPayType(payType);
        reqDto.setResponseType(responseType);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            AlipayAuthorizeResponseDto resDto = (AlipayAuthorizeResponseDto)tran.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("entryForm", resDto.getEntryForm());
            request.setAttribute("payType", payType);
            if ("1".equals(payType) || "2".equals(payType)) {
                request.setAttribute("centerTradeId", resDto.getCenterTradeId());
                request.setAttribute("custTxn", resDto.getCustTxn());
            }
            if ("1".equals(payType)) {
                request.setAttribute("payTimeJp", resDto.getPayTimeJp());
                request.setAttribute("payTimeCn", resDto.getPayTimeCn());
                request.setAttribute("buyerChargedAmountCny", resDto.getBuyerChargedAmountCny());
            } else if ("2".equals(payType)) {
                request.setAttribute("qrCode", resDto.getQrCode());
                request.setAttribute("qrCodeImgUrl", resDto.getQrCodeImgUrl());
                request.setAttribute("qrCodeSmallImgUrl", resDto.getQrCodeSmallImgUrl());
                request.setAttribute("qrCodeLargeImgUrl", resDto.getQrCodeLargeImgUrl());
            }
            forward(request, response, "./AuthorizeExec.jsp");
        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./AuthorizeExec.jsp");
        }
    }
}
