package jp.veritrans.tercerog.sample.web.alipay;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AlipayConfirmRequestDto;
import jp.veritrans.tercerog.mdk.dto.AlipayConfirmResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * Alipay決済の確認処理クラス。
 */
public class ConfirmExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */

    @Override
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        String orderNumber = request.getParameter("orderId");
        String responseType = request.getParameter("responseType");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderNumber)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Confirm.jsp");
            return;
        }
        AlipayConfirmRequestDto reqDto = new AlipayConfirmRequestDto();
        reqDto.setOrderId(orderNumber);
        reqDto.setResponseType(responseType);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            AlipayConfirmResponseDto resDto = (AlipayConfirmResponseDto)tran.execute();
            
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("centerTradeId", resDto.getCenterTradeId());
            request.setAttribute("custTxn", resDto.getCustTxn());
            request.setAttribute("payTimeJp", resDto.getPayTimeJp());
            request.setAttribute("payTimeCn", resDto.getPayTimeCn());
            request.setAttribute("buyerChargedAmountCny", resDto.getBuyerChargedAmountCny());

            forward(request, response, "./ConfirmExec.jsp");
        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./ConfirmExec.jsp");
        }
    }
}
