package jp.veritrans.tercerog.sample.web.amazonpay;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AmazonpayUpdateAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.AmazonpayUpdateAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * Amazon Pay決済確認処理クラス。
 */
public class AuthorizeConfirmExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    @Override
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        HttpSession session = request.getSession(true);
        String orderId = (String) session.getAttribute("orderId");
        String payRedirectUrl = (String) session.getAttribute("payRedirectUrl");

        // 金額に変更があれば更新のリクエストを実施する
        int originalAmount = (Integer) session.getAttribute("originalAmount");
        int amount = (Integer) session.getAttribute("amount");

        if (amount != originalAmount) {
            AmazonpayUpdateAuthorizeRequestDto reqDto = new AmazonpayUpdateAuthorizeRequestDto();
            reqDto.setOrderId(orderId);
            reqDto.setAmount(String.valueOf(amount));

            try {
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                AmazonpayUpdateAuthorizeResponseDto resDto = (AmazonpayUpdateAuthorizeResponseDto) tran.execute();

                if (resDto.getMstatus().equals("success")) {
                    if (resDto.getPayRedirectUrl() != null && resDto.getPayRedirectUrl() != "") {
                        payRedirectUrl = resDto.getPayRedirectUrl();
                    }
                } else {
                    // リクエスト失敗時は結果画面を表示します
                    request.setAttribute("orderId", resDto.getOrderId());
                    request.setAttribute("mStatus", resDto.getMstatus());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());
                    request.setAttribute("vResultCode", resDto.getVResultCode());

                    forward(request, response, "./AuthorizeExec.jsp");
                    return;
                }

            } catch (Exception ex) {
                // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                System.out.println("Exception Occured !");
                System.out.println("Exception Message: " + ex.getMessage());
                ex.printStackTrace();
                request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                forward(request, response, "./AuthorizeExec.jsp");
                return;
            }
        }

        // 処理に問題なければリダイレクトを実施する。
        response.sendRedirect(payRedirectUrl);
    }
}
