package jp.veritrans.tercerog.sample.web.amazonpay;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.apache.commons.lang.StringUtils;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AmazonpayAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.AmazonpayAuthorizeResponseDto;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * AmazonPay処理クラス。
 */
public class AuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    @Override
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        request.setCharacterEncoding("UTF-8");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 決済確認画面種別の取得
        String payConfirmScreenType = request.getParameter("payConfirmScreenType");
        // 決済確認画面URLの取得
        String payConfirmScreenUrl = request.getParameter("payConfirmScreenUrl");
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Authorize.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        AmazonpayAuthorizeRequestDto reqDto = new AmazonpayAuthorizeRequestDto();

        // サービスオプションタイプの設定
        //reqDto.setServiceOptionType(request.getParameter("serviceOptionType"));
        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // 与信同時売上フラグの設定
        if (MdkServiceConstants.AMAZONPAY_AUTH_WITH_CAPTURE.equals(request.getParameter("withCapture"))) {
            reqDto.setWithCapture("true");
        }
        // 配送先表示抑止フラグの設定
        if (MdkServiceConstants.AMAZONPAY_SUPPRESS_SHIPPING_ADDRESS_VIEW_TRUE
                .equals(request.getParameter("suppressShippingAddressView"))) {
            reqDto.setSuppressShippingAddressView("true");
        }
        // 注文説明の設定
        reqDto.setNoteToBuyer(request.getParameter("noteToBuyer"));
        // 完了時URLの設定
        reqDto.setSuccessUrl(request.getParameter("successUrl"));
        // キャンセル時URLの設定
        reqDto.setCancelUrl(request.getParameter("cancelUrl"));
        // エラー時URLの設定
        reqDto.setErrorUrl(request.getParameter("errorUrl"));
        // 決済確認画面種別の取得
        reqDto.setPayConfirmScreenType(payConfirmScreenType);
        // 決済確認画面URLの取得
        reqDto.setPayConfirmScreenUrl(payConfirmScreenUrl);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            AmazonpayAuthorizeResponseDto resDto = (AmazonpayAuthorizeResponseDto) tran.execute();

            // セッションに金額を保存
            HttpSession session = request.getSession(true);
            session.setAttribute("orderId", orderId);
            session.setAttribute("originalAmount", Integer.parseInt(amount));

            String responseContents = resDto.getResponseContents();
            if (StringUtils.isNotEmpty(responseContents)) {
                // レスポンスコンテンツがある場合はそのまま表示します。
                response.setContentType("text/html; charset=UTF-8");
                PrintWriter writer = response.getWriter();
                writer.println(responseContents);
            } else {
                // 結果画面を表示します
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());
                request.setAttribute("vResultCode", resDto.getVResultCode());

                forward(request, response, "./AuthorizeExec.jsp");
            }

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./AuthorizeExec.jsp");
        }
    }

}
