package jp.veritrans.tercerog.sample.web.bank;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.BankAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.BankAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 銀行決済処理クラス。
 */
public class AuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 決済サービスオプション
        String serviceOptionType = request.getParameter("serviceOptionType");
        // 取引ID
        String orderId = request.getParameter("orderId");
        // 決済金額
        String amount = request.getParameter("amount");
        // 顧客名1
        String name1 = request.getParameter("name1");
        // 顧客名2
        String name2 = request.getParameter("name2");
        // 顧客名カナ1
        String kana1 = request.getParameter("kana1");
        // 顧客名カナ2
        String kana2 = request.getParameter("kana2");
        // 支払期限
        String payLimit = request.getParameter("payLimit");
        // プッシュURL
        String pushUrl = request.getParameter("pushUrl");
        // 請求内容（漢字）
        String contents = request.getParameter("contents");
        // 請求内容（カナ）
        String contentsKana = request.getParameter("contentsKana");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        } else if (isNull(name1)) {
            warning = "<font color='#ff0000'><b>必須項目：顧客名1が指定されていません</b></font>";
        } else if (isNull(kana1)) {
            warning = "<font color='#ff0000'><b>必須項目：カナ1が指定されていません</b></font>";
        } else if (isNull(payLimit)) {
            warning = "<font color='#ff0000'><b>必須項目：支払期限が指定されていません</b></font>";
        } else if (isNull(contents)) {
            warning = "<font color='#ff0000'><b>必須項目：請求内容（漢字）が指定されていません</b></font>";
        } else if (isNull(contentsKana)) {
            warning = "<font color='#ff0000'><b>必須項目：請求内容（カナ）が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Authorize.jsp");
            return;
        }

        ResourceBundle rb = ResourceBundle.getBundle("bank");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        BankAuthorizeRequestDto reqDto = new BankAuthorizeRequestDto();

        reqDto.setServiceOptionType(serviceOptionType);
        reqDto.setOrderId(orderId);
        reqDto.setAmount(amount);
        reqDto.setName1(name1);
        reqDto.setName2(name2);
        reqDto.setKana1(kana1);
        reqDto.setKana2(kana2);
        reqDto.setPayLimit(payLimit);
        reqDto.setPushUrl(pushUrl);
        reqDto.setContents(contents);
        reqDto.setContentsKana(contentsKana);

        if ("netbank-pc".equals(serviceOptionType)) {
            // ネットバンク決済(PC)の場合にのみ"決済結果戻り先URL"を設定可能
            reqDto.setTermUrl(response.encodeURL(rb.getString("termUrl")));
        }

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(reqDto);
            BankAuthorizeResponseDto resDto = (BankAuthorizeResponseDto) transaction.execute();

            request.setAttribute("serviceOptionType", serviceOptionType);
            request.setAttribute("orderId", orderId);
            request.setAttribute("amount", amount);

            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg",
                    resDto.getMerrMsg() != null ? resDto.getMerrMsg() : "");
            request.setAttribute("vResultCode",
                    resDto.getVResultCode() != null ? resDto.getVResultCode() : "");
            if (serviceOptionType.startsWith("atm")) {
                // ATM決済は、収納機関番号、お客様番号、確認番号を完了画面に表示する。
                request.setAttribute("shunoKikanNo",
                        resDto.getShunoKikanNo() != null ? resDto.getShunoKikanNo() : "");
                request.setAttribute("customerNo",
                        resDto.getCustomerNo() != null ? resDto.getCustomerNo() : "");
                request.setAttribute("confirmNo",
                        resDto.getConfirmNo() != null ? resDto.getConfirmNo() : "");
            } else {
                // ネット決済
                String view = resDto.getView() != null ? resDto.getView() : "";
                // viewに戻り値がある場合は、そのviewの値を表示してください。
                if (isNull(view) == false) {
                    PrintWriter writer = response.getWriter();
                    writer.write(view);
                    writer.flush();
                    writer.close();
                    return;
                }
                /* viewに値がない場合は、指定されたURLへへリダイレクトする画面へ遷移させ */
                /* 決済結果から取得したURLへアクセスしてください。 */
                request.setAttribute("requestId",
                        resDto.getUrl() != null ? resDto.getRequestId() : "");
                request.setAttribute("url",
                        resDto.getUrl() != null ? resDto.getUrl() : "");
                request.setAttribute("shunoKikanNo",
                        resDto.getShunoKikanNo() != null ? resDto.getShunoKikanNo() : "");
                request.setAttribute("bill",
                        resDto.getConfirmNo() != null ? resDto.getBill(): "");
                request.setAttribute("billPattern",
                        resDto.getConfirmNo() != null ? resDto.getBillPattern() : "");
            }

            // 結果画面を表示します
            forward(request, response, "./AuthorizeExec.jsp");

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./AuthorizeExec.jsp");
        }
    }
}
