package jp.veritrans.tercerog.sample.web.card;


import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CardReAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardReAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * クレジットカード（本人認証無し）決済 再与信請求処理クラス。
 */
public class ReAuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 与信方法の取得
        String withCapture = request.getParameter("withCapture");
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 元取引IDの取得
        String originalOrderId = request.getParameter("originalOrderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 支払方法の取得
        String jpo1 = request.getParameter("jpo1");
        // 支払回数の取得
        String jpo2 = request.getParameter("jpo2");
        // セキュリティコードの取得
        String securityCode = request.getParameter("securityCode");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(originalOrderId)) {
            warning =  "<font color='#ff0000'><b>必須項目：元取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./ReAuthorize.jsp");
            return;
        }


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        CardReAuthorizeRequestDto reqDto = new CardReAuthorizeRequestDto();

        // 要求パラメータを設定します。
        // オーダーIDの設定
        reqDto.setOrderId(orderId);
        // 元取引IDの設定
        reqDto.setOriginalOrderId(originalOrderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // ペイメントオプション(支払方法・回数)の設定
        String jpo = null;
        if ("10".equals(jpo1) || "80".equals(jpo1)) {
            jpo = jpo1;
        } else if ("61".equals(jpo1) && jpo2 != null) {
            jpo = jpo1 + "C" + jpo2;
        }
        if (jpo != null) reqDto.setJpo(jpo);
        // セキュリティコード設定
        if (securityCode != null) reqDto.setSecurityCode(securityCode);
        // 与信方法によって、売上フラグを設定
        if ("1".equals(withCapture)) reqDto.setWithCapture("true");

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            CardReAuthorizeResponseDto resDto = (CardReAuthorizeResponseDto) tran.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("reqCardNumber", resDto.getReqCardNumber());
            request.setAttribute("centerReferenceNumber", resDto.getCenterReferenceNumber());

            // 結果画面を表示します
            forward(request, response, "./ReAuthorizeExec.jsp");

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./ReAuthorizeExec.jsp");
        }
    }

}
