package jp.veritrans.tercerog.sample.web.carrier.base;

import java.io.IOException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CarrierAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CarrierAuthorizeResponseDto;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.sample.util.CarrierUtility;
import jp.veritrans.tercerog.sample.util.Utils;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * キャリア決済処理クラス。
 */
public abstract class AbstractAuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    abstract protected String getJsp();

    abstract protected String getAuthorizeJsp();

    abstract protected void setCharacterEncoding(HttpServletRequest request) throws UnsupportedEncodingException;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        setCharacterEncoding(request);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // サービスオプションタイプ（キャリアの種類）の取得
        String serviceOptionType = request.getParameter("serviceOptionType");
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 課金種別の取得
        String accountingType = request.getParameter("accountingType");
        // 与信同時売上フラグの取得
        String withCapture = request.getParameter("withCapture");
        // 初回課金年月日の取得
        String mpFirstDate = request.getParameter("mpFirstDate");
        // 継続課金日の取得
        String mpDay = request.getParameter("mpDay");
        // S!まとめて支払い用UIDの設定
        String sbUid = null;
        if (serviceOptionType.equals(MdkServiceConstants.CARRIER_S_BIKKURI)) {
            sbUid = request.getParameter("sbUid");
            if (request.getParameter("dummyMode").equals("ダミーリクエスト")) {
                // S!まとめて支払いは、ヘッダ情報にx-jphone-uidが必須になります。
                // しかし、携帯端末以外でダミー決済を実施したい場合にはsbUidに任意の値を設定してください。
                sbUid = "DummyUid12345678";
            }
        }
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            if(!accountingType.equals(MdkServiceConstants.CARRIER_ONDEMAND)){
                warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
            }
        } else if (accountingType.equals(MdkServiceConstants.CARRIER_MONTHLY)) {
            // sofmaは継続の場合でも指定しないのでチェックしない。
            if (!serviceOptionType.equals(MdkServiceConstants.CARRIER_SB_MATOMETE)) {
                if (isNull(mpDay)) {
                    warning = "<font color='#ff0000'><b>必須項目：継続課金日が指定されていません</b></font>";
                } else if (isNull(mpFirstDate)) {
                    warning = "<font color='#ff0000'><b>必須項目：初回課金年月日が指定されていません</b></font>";
                }
            }
        } else if (serviceOptionType.equals(MdkServiceConstants.CARRIER_S_BIKKURI)) {
            if (sbUid == null) {
                warning = "<font color='#ff0000'><b>必須項目：リクエストヘッダからx-jphone-uidが取得できません。</b></font>";
            }
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, getAuthorizeJsp());
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        CarrierAuthorizeRequestDto reqDto = new CarrierAuthorizeRequestDto();

        // サービスオプションタイプ（キャリアの種類）の設定
        reqDto.setServiceOptionType(serviceOptionType);
        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // 端末種別の設定
        reqDto.setTerminalKind(request.getParameter("terminalKind"));
        // 商品タイプの設定
        reqDto.setItemType(request.getParameter("itemType"));
        // 課金種別の設定
        reqDto.setAccountingType(accountingType);
        if (accountingType.equals(MdkServiceConstants.CARRIER_MONTHLY)) {
            // 初回継続課金年月日の設定
            reqDto.setMpFirstDate(mpFirstDate);
            // 継続課金日の設定
            reqDto.setMpDay(mpDay);
        }
        // 与信同時売上フラグの設定
        if (MdkServiceConstants.CARRIER_AUTH_WITH_CAPTURE.equals(withCapture)) {
            reqDto.setWithCapture("true");
        }
        // 3Dセキュアの設定
        reqDto.setD3Flag(request.getParameter("d3Flag"));
        // 商品番号の設定
        reqDto.setItemId(request.getParameter("itemId"));
        // 商品情報の設定
        reqDto.setItemInfo(request.getParameter("itemInfo"));
        // 決済完了URLの設定
        reqDto.setSuccessUrl(request.getParameter("successUrl"));
        // 決済キャンセル時URLの設定
        reqDto.setCancelUrl(request.getParameter("cancelUrl"));
        // 決済エラー時URLの設定
        reqDto.setErrorUrl(request.getParameter("errorUrl"));
        // プッシュURLの設定
        reqDto.setPushUrl(request.getParameter("pushUrl"));
        // OpenIDの設定
        reqDto.setOpenId(request.getParameter("openId"));
        // S!まとめて支払い用UIDの設定
        reqDto.setSbUid(sbUid);
        // フレッツエリアの設定
        reqDto.setFletsArea(request.getParameter("fletsArea"));
        // auIDログインフラグの設定
        reqDto.setLoginAuId(request.getParameter("loginAuId"));

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            CarrierAuthorizeResponseDto resDto = (CarrierAuthorizeResponseDto)tran.execute();

            String responseContents = resDto.getResponseContents();
            String redirectUrl = resDto.getRedirectUrl();
            if (!Utils.isNull(responseContents)) {
                // レスポンスコンテンツがある場合はそのまま表示します。
                // キャリアによって文字コードが異なるため、ここで文字コードを指定してください。
                response.setContentType("text/html; charset="
                        + CarrierUtility.getEncoding(reqDto.getServiceOptionType(), reqDto.getTerminalKind()));
                PrintWriter writer = response.getWriter();
                writer.println(responseContents);
            } else if (!Utils.isNull(redirectUrl)) {
                // リダイレクトURLに値がある場合にはこのURLにリダイレクトします。
                response.sendRedirect(redirectUrl);
            } else {
                // 結果画面を表示します
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());
                request.setAttribute("vResultCode", resDto.getVResultCode());

                forward(request, response, getJsp());
            }

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, getJsp());
        }
    }

}
