package jp.veritrans.tercerog.sample.web.carrier.base;

import java.io.IOException;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CarrierCaptureRequestDto;
import jp.veritrans.tercerog.mdk.dto.CarrierCaptureResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * キャリア決済 売上請求処理クラス。
 */
public abstract class AbstractCaptureExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    abstract protected String getJsp();

    abstract protected String getCaptureJsp();

    abstract protected void setCharacterEncoding(HttpServletRequest request) throws UnsupportedEncodingException;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        setCharacterEncoding(request);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, getCaptureJsp());
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        CarrierCaptureRequestDto reqDto = new CarrierCaptureRequestDto();

        // サービスオプションタイプ（キャリアの種類）の設定
        reqDto.setServiceOptionType(request.getParameter("serviceOptionType"));
        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 課金売上月の設定
        reqDto.setCaptureMonth(request.getParameter("captureMonth"));

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            CarrierCaptureResponseDto resDto = (CarrierCaptureResponseDto)tran.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("captureDatetime", resDto.getCaptureDatetime());

            // 結果画面を表示します
            forward(request, response, getJsp());

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, getJsp());
        }
    }

}
