package jp.veritrans.tercerog.sample.web.cvs;


import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CvsAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CvsAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * コンビニ決済処理クラス。
 */
public class AuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータの取得。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = (String) request.getParameter("orderId");
        // 決済サービスオプション
        String serviceOptionType = request.getParameter("serviceOptionType");
        // 決済金額
        String amount = request.getParameter("amount");
        // 姓
        String name1 = request.getParameter("name1");
        // 名
        String name2 = request.getParameter("name2");
        // 電話番号
        String telNo = request.getParameter("telNo");
        // 支払期限
        String payLimit = request.getParameter("payLimit");
        // 支払期限時分
        String payLimitHhmm = request.getParameter("payLimitHhmm");
        // プッシュURL
        String pushUrl = request.getParameter("pushUrl");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        } else if (isNull(name1)) {
            warning =  "<font color='#ff0000'><b>必須項目：姓が指定されていません</b></font>";
        } else if (isNull(name2)) {
            warning =  "<font color='#ff0000'><b>必須項目：名が指定されていません</b></font>";
        } else if (isNull(telNo)) {
            warning =  "<font color='#ff0000'><b>必須項目：電話番号が指定されていません</b></font>";
        } else if (isNull(payLimit)) {
            warning =  "<font color='#ff0000'><b>必須項目：支払期限が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Authorize.jsp");
            return;
        }


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        CvsAuthorizeRequestDto reqDto = new CvsAuthorizeRequestDto();
        // 取引IDの採番と設定
        reqDto.setOrderId(orderId);
        // 支払区分（固定値）を設定
        reqDto.setPaymentType("0");

        // パラメタから取得した値を設定
        reqDto.setServiceOptionType(serviceOptionType);
        reqDto.setAmount(amount);
        reqDto.setName1(name1);
        reqDto.setName2(name2);
        reqDto.setTelNo(telNo);
        reqDto.setPayLimit(payLimit);
        reqDto.setPayLimitHhmm(payLimitHhmm);
        reqDto.setPushUrl(pushUrl);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(reqDto);
            CvsAuthorizeResponseDto resDto = (CvsAuthorizeResponseDto) transaction.execute();

            request.setAttribute("serviceOptionType", serviceOptionType);
            request.setAttribute("orderId", orderId);
            request.setAttribute("amount", amount);
            request.setAttribute("payLimit", payLimit);

            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg",  resDto.getMerrMsg() != null ? resDto.getMerrMsg() : "");
            request.setAttribute("vResultCode", resDto.getVResultCode() != null ? resDto.getVResultCode() : "");
            request.setAttribute("receiptNo", resDto.getReceiptNo() != null ? resDto.getReceiptNo() : "");
            request.setAttribute("haraikomiUrl", resDto.getHaraikomiUrl() != null ? resDto.getHaraikomiUrl() : "");

            // 結果画面を表示します
            forward(request, response, "./AuthorizeExec.jsp");

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./AuthorizeExec.jsp");
        }
    }

}
