package jp.veritrans.tercerog.sample.web.em;

import java.io.IOException;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.EmReAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.EmReAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 電子マネー決済 再決済請求処理クラス。
 */
public class ReAuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = request.getParameter("orderId");
        // 決済サービスオプション
        String serviceOptionType = request.getParameter("serviceOptionType");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./ReAuthorize.jsp");
            return;
        }

        ResourceBundle rb = ResourceBundle.getBundle("em");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        EmReAuthorizeRequestDto reqDto = new EmReAuthorizeRequestDto();
        // 取引ID
        reqDto.setOrderId(orderId);
        // 決済サービスオプション
        reqDto.setServiceOptionType(serviceOptionType);
        // 復旧リダイレクションURL
        reqDto.setReAuthorizeRedirectionUrl(response.encodeURL(rb.getString("tcc.reAuthorizeRedirectionUrl")));

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // コマンドを実行し、応答DTOを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        try {
            ITransaction transaction = TransactionFactory.getInstance(reqDto);
            // 再決済申込応答文
            EmReAuthorizeResponseDto resDto = (EmReAuthorizeResponseDto) transaction.execute();

            if ("success".equals(resDto.getMstatus())) {
                // リダイレクト
                response.setStatus(HttpServletResponse.SC_MOVED_PERMANENTLY);
                response.setHeader("Location", resDto.getReAuthAppUrl());
            } else {
                request.setAttribute("orderKind", "reAuthorize");
                request.setAttribute("serviceOptionType", serviceOptionType);
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());
                request.setAttribute("vResultCode", resDto.getVResultCode());
                request.setAttribute("reAuthAppUrl", resDto.getReAuthAppUrl());
                forward(request, response, "./ReAuthorizeExec.jsp");
            }

        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./ReAuthorizeExec.jsp");
        }
    }
}
