package jp.veritrans.tercerog.sample.web.em;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.EmRefundRequestDto;
import jp.veritrans.tercerog.mdk.dto.EmRefundResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 電子マネー決済 返金請求処理クラス。
 */
public class RefundExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 決済サービスオプション
        String serviceOptionType = request.getParameter("serviceOptionType");
        // 決済金額
        String amount = request.getParameter("amount");
        // オーダー種別
        String orderKind = request.getParameter("orderKind");
        // 返金対象取引ID
        String refundOrderId = request.getParameter("refundOrderId");
        // 決済期限
        String settlementLimit = request.getParameter("settlementLimit");
        // 画面タイトル
        String screenTitle = request.getParameter("screenTitle");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        } else if (isNull(orderKind)) {
            warning = "<font color='#ff0000'><b>必須項目：取引種別が指定されていません</b></font>";
        } else if (isNull(refundOrderId)) {
            warning = "<font color='#ff0000'><b>必須項目：対象取引IDが指定されていません</b></font>";
        } else if (!"edy-mobile".equals(serviceOptionType) //
                && !"edy-pc".equals(serviceOptionType) //
                && !"edy-direct".equals(serviceOptionType)  //
                && !"waon-pc".equals(serviceOptionType) //
                && !"waon-mobile".equals(serviceOptionType) //
                && isNull(settlementLimit)) {
            warning = "<font color='#ff0000'><b>必須項目：決済期限が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Refund.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        EmRefundRequestDto reqDto = new EmRefundRequestDto();
        // 取引IDの採番と設定
        String orderId = String.valueOf(System.currentTimeMillis());
        reqDto.setOrderId(orderId);

        if (serviceOptionType.startsWith("suica")) {
            // Suica決済の場合
            reqDto.setScreenTitle(screenTitle);

        } else if ("waon-pc".equals(serviceOptionType)) {
            // WAON PaSoRi決済の場合
            /* サンプルのためダミーURLを設定 */
            reqDto.setSuccessUrl(response.encodeURL("http://127.0.0.1/web/PaymentMethodSelect?status=success"));
            reqDto.setFailureUrl(response.encodeURL("http://127.0.0.1/web/PaymentMethodSelect?status=failure"));
            reqDto.setCancelUrl(response.encodeURL("http://127.0.0.1/web/PaymentMethodSelect?status=cancel"));
        }

        if (!"edy-mobile".equals(serviceOptionType) //
                && !"edy-pc".equals(serviceOptionType) //
                && !"edy-direct".equals(serviceOptionType) //
                && !"waon-pc".equals(serviceOptionType) //
                && !"waon-mobile".equals(serviceOptionType)) {
            reqDto.setSettlementLimit(settlementLimit);
        }

        // パラメタから取得した値を設定
        reqDto.setServiceOptionType(serviceOptionType);
        reqDto.setAmount(amount);
        reqDto.setOrderId(orderId);
        reqDto.setOrderKind(orderKind);
        reqDto.setRefundOrderId(refundOrderId);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(reqDto);
            EmRefundResponseDto resDto = (EmRefundResponseDto) transaction.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());

            request.setAttribute("receiptNo", resDto.getReceiptNo());
            request.setAttribute("appUrl", resDto.getAppUrl());

            // 結果画面を表示します
            forward(request, response, "./RefundExec.jsp");

        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./RefundExec.jsp");
        }
    }
}
