package jp.veritrans.tercerog.sample.web.linepay;

import java.io.IOException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.LinepayAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.LinepayAuthorizeResponseDto;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.sample.util.Utils;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * LINE Pay処理クラス。
 */
public class AuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        request.setCharacterEncoding("UTF-8");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 与信同時売上フラグの取得
        String withCapture = request.getParameter("withCapture");
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Authorize.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        LinepayAuthorizeRequestDto reqDto = new LinepayAuthorizeRequestDto();

        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // 与信同時売上フラグの設定
        if (MdkServiceConstants.LINEPAY_AUTH_WITH_CAPTURE.equals(withCapture)) {
            reqDto.setWithCapture("true");
        }
        // 商品番号の設定
        reqDto.setItemId(request.getParameter("itemId"));
        // 商品名の設定
        reqDto.setItemName(request.getParameter("itemName"));
        // 商品画像URLの設定
        reqDto.setItemImageUrl(request.getParameter("itemImageUrl"));
        // 使用ブラウザ判定の設定
        if (MdkServiceConstants.LINEPAY_CHECK_USE_BROWSER.equals(request.getParameter("checkUseBrowser"))) {
            reqDto.setCheckUseBrowser("true");
        }
        // アプリ起動URLスキームの設定
        reqDto.setAppUrlScheme(request.getParameter("appUrlScheme"));
        // 独自アプリの設定
        String useOriginalApp = request.getParameter("useOriginalApp");
        reqDto.setUseOriginalApp(useOriginalApp);
        // packageNameの設定
        reqDto.setPackageName(request.getParameter("packageName"));
        // 決済完了URLの設定
        reqDto.setSuccessUrl(request.getParameter("successUrl"));
        // 決済キャンセルURLの設定
        reqDto.setCancelUrl(request.getParameter("cancelUrl"));
        // 決済エラー時URLの設定
        reqDto.setErrorUrl(request.getParameter("errorUrl"));
        // 決済確認方法の設定
        reqDto.setPaymentConfirmType(request.getParameter("paymentConfirmType"));
        // ワンタイムキーの設定
        reqDto.setOneTimeKey(request.getParameter("oneTimeKey"));
        // プッシュURLの設定
        reqDto.setPushUrl(request.getParameter("pushUrl"));

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            LinepayAuthorizeResponseDto resDto = (LinepayAuthorizeResponseDto)tran.execute();

            String redirecturl = resDto.getRedirectWebUrl();

            // アプリからLINEを起動する場合には以下を使用してください。
            // ※使用方法については、開発ガイド参照
            // resDto.getRedirectAppUrl();

            if (!Utils.isNull(redirecturl)) {
                response.sendRedirect(redirecturl);
            } else {
                // 結果画面を表示します
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());
                request.setAttribute("vResultCode", resDto.getVResultCode());

                forward(request, response, "./AuthorizeExec.jsp");
            }

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./AuthorizeExec.jsp");
        }
    }

}
