package jp.veritrans.tercerog.sample.web.mpi;


import java.io.IOException;
import java.io.PrintWriter;
import java.util.*;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MpiGetResultRequestDto;
import jp.veritrans.tercerog.mdk.dto.MpiGetResultResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * クレジットカード（本人認証あり）決済本人認証結果取得処理クラス。
 */
public class GetResultExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./GetResult.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        MpiGetResultRequestDto reqDto = new MpiGetResultRequestDto();

        // 要求パラメータを設定します。
        // 取引IDの設定
        reqDto.setOrderId(orderId);

        PrintWriter out = null;
        try {
            out = response.getWriter();

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            MpiGetResultResponseDto resDto = (MpiGetResultResponseDto) tran.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            // 個別項目
            request.setAttribute("requestId", resDto.getRequestId());
            request.setAttribute("reqAmount", resDto.getReqAmount());
            request.setAttribute("reqCardNumber", resDto.getReqCardNumber());
            request.setAttribute("mpiMstatus", resDto.getMpiMstatus());
            request.setAttribute("mpiVresultCode", resDto.getMpiVresultCode());
            request.setAttribute("cardMstatus", resDto.getCardMstatus());
            request.setAttribute("authCode", resDto.getAuthCode());
            request.setAttribute("dddMessageVersion", resDto.getDddMessageVersion());
            request.setAttribute("dddTransactionId", resDto.getDddTransactionId());
            request.setAttribute("dddDsTransactionId", resDto.getDddDsTransactionId());
            request.setAttribute("dddServerTransactionId", resDto.getDddServerTransactionId());
            request.setAttribute("dddTransactionStatus", resDto.getDddTransactionStatus());
            request.setAttribute("dddCavvAlgorithm", resDto.getDddCavvAlgorithm());
            request.setAttribute("dddCavv", resDto.getDddCavv());
            request.setAttribute("dddEci", resDto.getDddEci());

            // 解析画面を表示します
            forward(request, response, "./GetResultExec.jsp");
        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、
            // Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./GetResultExec.jsp");
            return;
        } finally {
            if (out != null) {
                out.close();
            }
        }
    }

}
