package jp.veritrans.tercerog.sample.web.mpi;

import java.io.IOException;
import java.util.*;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MpiReAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.MpiReAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * クレジットカード（本人認証あり）決済再与信処理クラス。
 */
public class ReAuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 設定ファイルより取得する。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // mpi.propertiesファイルから必要なプロパティを取得
        Locale objLcl = request.getLocale();
        ResourceBundle rb = ResourceBundle.getBundle("mpi",objLcl);
        String termUrl = rb.getString("termUrl");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 元取引IDの取得
        String originalOrderId = request.getParameter("originalOrderId");
        // 決済金額の取得
        String amount = request.getParameter("amount");
        // 決済種別の取得
        //   1: 3D-Secure認証のみ(決済しない)
        //   2: 完全認証(3D-Secure認証が完全に成功した場合のみ決済する)
        //   3: 通常認証(カード会社リスク負担にて決済する)
        //   4: 通常認証(カード会社か加盟店リスク負担にて決済する)
        String paymentMode = request.getParameter("paymentMode");
        // 支払方法の取得
        String jpo1 = request.getParameter("jpo1");
        // 支払回数の取得
        String jpo2 = request.getParameter("jpo2");
        // セキュリティコードの取得
        String securityCode = request.getParameter("securityCode");
        // プッシュ通知先URLの取得
        String pushUrl = request.getParameter("pushUrl");
        // HTTP-Acceptの取得
        String httpAccept = request.getHeader("Accept");
        // HTTP-USERAGENTの取得
        String userAgent = request.getHeader("User-Agent");

        HttpSession session = request.getSession(true);
        session.setAttribute("paymentMode", paymentMode);
        // 再与信である事を示すフラグをセッションに格納
        session.setAttribute("reAuthorizeFlg", "1");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(originalOrderId)) {
            warning =  "<font color='#ff0000'><b>必須項目：元取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./ReAuthorize.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        MpiReAuthorizeRequestDto reqDto = new MpiReAuthorizeRequestDto();

        // 要求パラメータを設定します。
        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 元取引IDの設定
        reqDto.setOriginalOrderId(originalOrderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // ペイメントオプション(支払方法・回数)の設定
        String jpo = null;
        if ("10".equals(jpo1) || "80".equals(jpo1)) {
            jpo = jpo1;
        } else if ("61".equals(jpo1) && jpo2 != null) {
            jpo = jpo1 + "C" + jpo2;
        }
        if (jpo != null) reqDto.setJpo(jpo);
        // セキュリティコード設定
        reqDto.setSecurityCode(securityCode);
        // プッシュ通知先URL設定
        reqDto.setPushUrl(pushUrl);
        // サービスオプションタイプの設定（固定値）
        if ("1".equals(paymentMode)) {
            reqDto.setServiceOptionType("mpi-none");
        } else if (paymentMode.equals("2")) {
            reqDto.setServiceOptionType("mpi-complete");
        } else if (paymentMode.equals("3")) {
            reqDto.setServiceOptionType("mpi-company");
        } else if (paymentMode.equals("4")) {
            reqDto.setServiceOptionType("mpi-merchant");
        } else {}
        // 売上フラグ
        reqDto.setWithCapture(request.getParameter("withCapture"));
        // Acceptの設定
        reqDto.setHttpAccept(httpAccept);
        // UserAgentの設定
        reqDto.setHttpUserAgent(userAgent);
        // RedirectionURLの設定
        reqDto.setRedirectionUri(termUrl);
        // 端末種別の設定
        reqDto.setBrowserDeviceCategory(request.getParameter("browserDeviceCategory"));
        // 本人認証有効期限の設定
        reqDto.setVerifyTimeout(request.getParameter("verifyTimeout"));
        // デバイスチャネルの設定
        reqDto.setDeviceChannel(request.getParameter("deviceChannel"));
        // アカウントタイプの設定
        reqDto.setAccountType(request.getParameter("accountType"));
        // 認証要求タイプの設定
        reqDto.setAuthenticationIndicator(request.getParameter("authenticationIndicator"));
        // カード保有者名の設定
        reqDto.setCardholderName(request.getParameter("cardholderName"));
        // カード保有者メールアドレスの設定
        reqDto.setCardholderEmail(request.getParameter("cardholderEmail"));
        // カード保有者自宅電話番号国コードの設定
        reqDto.setCardholderHomePhoneCountry(request.getParameter("cardholderHomePhoneCountry"));
        // カード保有者自宅電話番号の設定
        reqDto.setCardholderHomePhoneNumber(request.getParameter("cardholderHomePhoneNumber"));
        // カード保有者携帯電話番号国コードの設定
        reqDto.setCardholderMobilePhoneCountry(request.getParameter("cardholderMobilePhoneCountry"));
        // カード保有者携帯電話番号の設定
        reqDto.setCardholderMobilePhoneNumber(request.getParameter("cardholderMobilePhoneNumber"));
        // カード保有者勤務先電話番号国コードの設定
        reqDto.setCardholderWorkPhoneCountry(request.getParameter("cardholderWorkPhoneCountry"));
        // カード保有者勤務先電話番号の設定
        reqDto.setCardholderWorkPhoneNumber(request.getParameter("cardholderWorkPhoneNumber"));
        // 請求先住所_市区町村の設定
        reqDto.setBillingAddressCity(request.getParameter("billingAddressCity"));
        // 請求先住所_国の設定
        reqDto.setBillingAddressCountry(request.getParameter("billingAddressCountry"));
        // 請求先住所1の設定
        reqDto.setBillingAddressLine1(request.getParameter("billingAddressLine1"));
        // 請求先住所2の設定
        reqDto.setBillingAddressLine2(request.getParameter("billingAddressLine2"));
        // 請求先住所3の設定
        reqDto.setBillingAddressLine3(request.getParameter("billingAddressLine3"));
        // 請求先郵便番号の設定
        reqDto.setBillingPostalCode(request.getParameter("billingPostalCode"));
        // 請求先住所_都道府県の設定
        reqDto.setBillingAddressState(request.getParameter("billingAddressState"));
        // 配送先住所_市区町村の設定
        reqDto.setShippingAddressCity(request.getParameter("shippingAddressCity"));
        // 配送先住所_国の設定
        reqDto.setShippingAddressCountry(request.getParameter("shippingAddressCountry"));
        // 配送先住所1の設定
        reqDto.setShippingAddressLine1(request.getParameter("shippingAddressLine1"));
        // 配送先住所2の設定
        reqDto.setShippingAddressLine2(request.getParameter("shippingAddressLine2"));
        // 配送先住所3の設定
        reqDto.setShippingAddressLine3(request.getParameter("shippingAddressLine3"));
        // 配送先郵便番号の設定
        reqDto.setShippingPostalCode(request.getParameter("shippingPostalCode"));
        // 配送先住所_都道府県の設定
        reqDto.setShippingAddressState(request.getParameter("shippingAddressState"));
        // 消費者IPアドレスの設定
        reqDto.setCustomerIp(request.getParameter("customerIp"));
        // チャレンジ認証フラグの設定
        reqDto.setWithChallenge(request.getParameter("withChallenge"));

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            MpiReAuthorizeResponseDto resDto = (MpiReAuthorizeResponseDto) tran.execute();

            // ログ
            System.out.println("PaymentMode["+paymentMode+"] : vResultCode="+resDto.getVResultCode());

            String authStartUrl = resDto.getAuthStartUrl();

            if ("success".equals(resDto.getMstatus())) {
                response.sendRedirect(authStartUrl);
            } else {
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());
                request.setAttribute("vResultCode", resDto.getVResultCode());

                forward(request, response, "./ReAuthorizeExec.jsp");
                return;
            }
        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、
            // Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./ReAuthorizeExec.jsp");
            return;
        }
    }

}
