package jp.veritrans.tercerog.sample.web.paynowid;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AccountAddRequestDto;
import jp.veritrans.tercerog.mdk.dto.AccountAddResponseDto;
import jp.veritrans.tercerog.mdk.dto.AccountRestoreRequestDto;
import jp.veritrans.tercerog.mdk.dto.AccountRestoreResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 会員入会、会員再入会処理クラス
 */
public class AccountEntryExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 会員IDの取得
        String accountId = request.getParameter("accountId");
        // 入会年月日の取得
        String createDate = request.getParameter("createDate");
        // 入会処理区分の取得
        String entryKbn = request.getParameter("entryKbn");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        // 会員ID
        if (isNull(accountId) == true) {
            warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
        }
        // 入会処理区分
        if (isNull(entryKbn) == true) {
            warning =  "<font color='#ff0000'><b>必須項目：入会処理区分 が指定されていません</b></font>";
        } else if (!"1".equals(entryKbn) && !"2".equals(entryKbn)) {
            warning =  "<font color='#ff0000'><b>不正な入会処理区分です </b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./AccountEntry.jsp");
            return;
        }

        if ("1".equals(entryKbn)) {

            // 新規入会 //

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            AccountAddRequestDto reqDto = new AccountAddRequestDto();
            // 会員ID設定
            reqDto.setAccountId(accountId);
            // 入会日
            reqDto.setCreateDate(createDate);

            try {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction transaction = TransactionFactory.getInstance(reqDto);
                AccountAddResponseDto resDto = (AccountAddResponseDto) transaction.execute();
                
                if (resDto.getPayNowIdResponse() != null) {
                    request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                    request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                }
                request.setAttribute("vResultCode", resDto.getVResultCode());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());

                // 結果画面を表示します
                forward(request, response, "./AccountEntryExec.jsp");

            } catch (Exception ex) {
                System.out.println("Exception Occured !");
                System.out.println("Exception Message: " + ex.getMessage());
                ex.printStackTrace();
                request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                forward(request, response,  "./AccountEntryExec.jsp");
            }

        } else {

            // 再入会 //

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            AccountRestoreRequestDto reqDto = new AccountRestoreRequestDto();
            // 会員ID設定
            reqDto.setAccountId(accountId);
            // 入会日
            reqDto.setCreateDate(createDate);

            try {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction transaction = TransactionFactory.getInstance(reqDto);
                AccountRestoreResponseDto resDto = (AccountRestoreResponseDto) transaction.execute();

                if (resDto.getPayNowIdResponse() != null) {
                    request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                    request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                }
                request.setAttribute("vResultCode", resDto.getVResultCode());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());

                // 結果画面を表示します
                forward(request, response, "./AccountEntryExec.jsp");

            } catch (Exception ex) {
                System.out.println("Exception Occured !");
                System.out.println("Exception Message: " + ex.getMessage());
                ex.printStackTrace();
                request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                forward(request, response,  "./AccountEntryExec.jsp");
            }
        }
    }

}
