package jp.veritrans.tercerog.sample.web.paynowid;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CardInfo;
import jp.veritrans.tercerog.mdk.dto.CardInfoGetRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardInfoGetResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * カード情報取得クラス(カード決済本人認証なし)
 */
public class CardAuthorizeSelect extends MdkSampleBaseServlet {

    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 会員ID
        String accountId = request.getParameter("accountId");
        // 取引ID
        String orderId = request.getParameter("orderId");
        // 金額
        String amount = request.getParameter("amount");
        // 与信方法
        String withCapture = request.getParameter("withCapture");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        } else if (isNull(accountId)) {
            warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./CardAuthorize.jsp");
            return;
        }

        // Dtoの生成
        CardInfoGetRequestDto reqDto = new CardInfoGetRequestDto();
        reqDto.setAccountId(accountId);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            CardInfoGetResponseDto resDto = (CardInfoGetResponseDto) tran.execute();

            // 処理結果を取得する
            String mStatus = resDto.getMstatus();

            if ("success".equals(mStatus)) {
                // 成功の場合、カード選択画面に遷移
                // カード情報
                CardInfo[] cardResults = resDto.getPayNowIdResponse().getAccount().getCardInfo();
                // カード情報の数
                String cardCnt = String.valueOf(cardResults.length);
                request.setAttribute("cardSize", cardCnt);
                // カード情報分繰り返す
                for (int i=0; i < cardResults.length; i++) {
                    // カード番号
                    request.setAttribute("maskCardNumber" + String.valueOf(i), cardResults[i].getCardNumber());
                    // 有効期限
                    request.setAttribute("cardExpire" + String.valueOf(i), cardResults[i].getCardExpire());
                    // カードID
                    request.setAttribute("cardId" + String.valueOf(i), cardResults[i].getCardId());
                }
                // 会員ID
                request.setAttribute("accountId", accountId);
                // 金額
                request.setAttribute("amount", amount);
                // 与信方法
                request.setAttribute("withCapture", withCapture);

                forward(request, response, "./CardAuthorizeSelect.jsp");
            } else {
                // それ以外の場合、決済結果画面に遷移
                // 取引ID
                request.setAttribute("orderId", orderId);
                // 取引ステータス
                request.setAttribute("mStatus", mStatus);
                // 結果コード
                request.setAttribute("vResultCode", resDto.getVResultCode());
                // 結果メッセージ
                request.setAttribute("mErrMsg", resDto.getMerrMsg());
                // PayNowIDステータス
                if (resDto.getPayNowIdResponse() != null) {
                    request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                }
                forward(request, response, "./CardAuthorizeExec.jsp");
            }
        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./CardAuthorizeExec.jsp");
        }
    }

}
