package jp.veritrans.tercerog.sample.web.paypal;

import java.io.IOException;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.PaypalAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.PaypalAuthorizeResponseDto;
import jp.veritrans.tercerog.mdk.dto.PaypalCaptureRequestDto;
import jp.veritrans.tercerog.mdk.dto.PaypalCaptureResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * ペイパル決済処理クラス。
 */
public class AuthorizeInit extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException,
            IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 設定ファイルより取得する。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // paypal.propertiesファイルから必要なプロパティを取得
        Locale objLcl = request.getLocale();
        ResourceBundle rb = ResourceBundle.getBundle("paypal",objLcl);
        String returnUrl = rb.getString("return.url");
        String cancelUrl = rb.getString("cancel.url");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 決済方法の取得
        String paymentAction = request.getParameter("paymentAction");

        HttpSession session = request.getSession(true);
        session.setAttribute("paymentAction", paymentAction);

        try {
            if ("authorize".equals(paymentAction)) {
            // 与信のみ
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 要求DTOを生成し、値を設定します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                PaypalAuthorizeRequestDto reqDto = new PaypalAuthorizeRequestDto();

                // 要求パラメータを設定します。
                // アクションの設定
                reqDto.setAction("set");
                // オーダーIDの設定
                reqDto.setOrderId(orderId);
                // 金額の設定
                reqDto.setAmount(amount);
                // リターンURL
                reqDto.setReturnUrl(returnUrl);
                // キャンセルURL
                reqDto.setCancelUrl(cancelUrl + "?txnType=" + request.getParameter("txnType"));
                // 確認済住所フラグ
                reqDto.setShippingFlag("0");

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                PaypalAuthorizeResponseDto resDto = (PaypalAuthorizeResponseDto) tran.execute();

                if ("success".equals(resDto.getMstatus())) {
                // 成功の場合（paypal.comへリダイレクト）
                    response.sendRedirect(response.encodeRedirectURL(resDto.getLoginUrl()));
                } else {
                // 失敗の場合
                    request.setAttribute("orderId", resDto.getOrderId());
                    request.setAttribute("mStatus", resDto.getMstatus());
                    request.setAttribute("vResultCode", resDto.getVResultCode());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());

                    // 結果画面を表示します
                    forward(request, response, "./AuthorizeInit.jsp");
                }
            } else {
            // 与信同時売上
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 要求DTOを生成し、値を設定します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                PaypalCaptureRequestDto reqDto = new PaypalCaptureRequestDto();

                // 要求パラメータを設定します。
                // アクションの設定
                reqDto.setAction("set");
                // オーダーIDの設定
                reqDto.setOrderId(orderId);
                // 金額の設定
                reqDto.setAmount(amount);
                // リターンURL
                reqDto.setReturnUrl(returnUrl);
                // キャンセルURL
                reqDto.setCancelUrl(cancelUrl + "?txnType=" + request.getParameter("txnType"));
                // 確認済住所フラグ
                reqDto.setShippingFlag("0");

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                PaypalCaptureResponseDto resDto = (PaypalCaptureResponseDto) tran.execute();

                if ("success".equals(resDto.getMstatus())) {
                // 成功の場合（paypal.comへリダイレクト）
                    response.sendRedirect(response.encodeRedirectURL(resDto.getLoginUrl()));
                } else {
                // 失敗の場合
                    request.setAttribute("orderId", resDto.getOrderId());
                    request.setAttribute("mStatus", resDto.getMstatus());
                    request.setAttribute("vResultCode", resDto.getVResultCode());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());

                    // 結果画面を表示します
                    forward(request, response, "./AuthorizeInit.jsp");
                }
            }
        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./AuthorizeInit.jsp");
        }
    }
}