package jp.veritrans.tercerog.sample.web.paypay;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.PaypayAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.PaypayAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Utils;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * PayPay(オンライン決済)処理クラス。
 */
public class OnlineAuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        request.setCharacterEncoding("UTF-8");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./OnlineAuthorize.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        PaypayAuthorizeRequestDto reqDto = new PaypayAuthorizeRequestDto();

        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);

        // 商品名の設定
        reqDto.setItemName(request.getParameter("itemName"));
        // 商品IDの設定
        reqDto.setItemId(request.getParameter("itemId"));
        // 決済完了URLの設定
        reqDto.setSuccessUrl(request.getParameter("successUrl"));
        // 決済キャンセルURLの設定
        reqDto.setCancelUrl(request.getParameter("cancelUrl"));
        // 決済エラー時URLの設定
        reqDto.setErrorUrl(request.getParameter("errorUrl"));
        // プッシュ先URLの設定
        reqDto.setPushUrl(request.getParameter("pushUrl"));

        // サービスオプションタイプの設定
        reqDto.setServiceOptionType(MdkServiceConstants.PAYPAY_ONLINE);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            PaypayAuthorizeResponseDto resDto = (PaypayAuthorizeResponseDto) tran.execute();

            String responseContents = resDto.getResponseContents();
            if (!Utils.isNull(responseContents)) {
                // レスポンスコンテンツがある場合はそのまま表示します。
                response.setContentType("text/html; charset=Shift_JIS");
                PrintWriter writer = response.getWriter();
                writer.println(responseContents);
            } else {
                // 結果画面を表示します
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());
                request.setAttribute("vResultCode", resDto.getVResultCode());

                forward(request, response, "./OnlineAuthorizeExec.jsp");
            }

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./OnlineAuthorizeExec.jsp");
        }
    }

}
