package jp.veritrans.tercerog.sample.web.recruit;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
//import java.security.MessageDigest;
//import java.security.NoSuchAlgorithmException;
import java.util.Locale;
import java.util.Map;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

//import org.apache.commons.codec.binary.Base64;

import jp.veritrans.tercerog.mdk.util.AuthHashUtil;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 楽天結果通知処理クラス。
 */
public class Result extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;
//    // デフォルトのアルゴリズム
//    private static final String DEFAULT_ALGORITHM_NAME = "SHA-256";
    // デフォルトの文字コード
    private static final String DEFAULT_CHARSET = "UTF-8";

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // エラー情報の初期化
        String warning = null;

        // 3GPSMDK.propertiesファイルから必要な値を取得。
        Locale objLcl = request.getLocale();
        ResourceBundle rb = ResourceBundle.getBundle("3GPSMDK", objLcl);

        // マーチャントCCIDの取得
        String merchantCcId = rb.getString("MERCHANT_CCID");
        // マーチャントパスワードの取得
        String merchantPw = rb.getString("MERCHANT_SECRET_KEY");

        // ハッシュ値による改竄チェック
        try {
            Map requestParamMap = request.getParameterMap();

            // リクエストパラメータ（パラメータ順序、改竄チェック用ハッシュ値を含む）、
            // マーチャントCCID、マーチャントパスワード、文字コードを用いて、
            // 改竄チェックを行う。
            boolean checkResult = AuthHashUtil.checkAuthHash(requestParamMap, merchantCcId, merchantPw,
                 DEFAULT_CHARSET);
            if (!checkResult) {
                warning = "<font color='#ff0000'><b>【パラメータ改竄】パラメータ情報が改竄されています。</b></font>";
            }
        } catch (UnsupportedEncodingException e) {
            throw new ServletException("Unsupported charset : " + DEFAULT_CHARSET);
        }

        // MDKを使用せずに改竄チェックを行う例
//        try {
//            // 連結したパラメータ（リクエスト、パラメータ順序、マーチャントCCID、マーチャントパスワード）、アルゴリズム、文字コードでハッシュ値を算出する。
//            String hash = createAuthHashInfo(request, merchantCcId, merchantPw,
//                    DEFAULT_ALGORITHM_NAME, DEFAULT_CHARSET);
//            // 改ざんチェック用ハッシュ値の取得
//            String vAuthInfo = request.getParameter("vAuthInfo");
//            // 算出したハッシュ値とパラメータ取得したハッシュ値を比較し、異なる場合は改竄とみなす。
//            if (hash == null || vAuthInfo == null || hash.equals(vAuthInfo) == false) {
//                warning = "<font color='#ff0000'><b>【パラメータ改竄】パラメータ情報が改竄されています。</b></font>";
//            }
//        } catch (NoSuchAlgorithmException e) {
//            throw new ServletException("Unsupported algorithm : " + DEFAULT_ALGORITHM_NAME);
//        } catch (UnsupportedEncodingException e) {
//            throw new ServletException("Unsupported charset : " + DEFAULT_CHARSET);
//        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
        }

        // 結果通知画面の表示
        forward(request, response, "./Result.jsp");
    }

//    /**
//     * ハッシュ値算出
//     *
//     * @param request
//     * @param merchantCcId
//     * @param merchantPw
//     * @param algorithmName
//     * @param charset
//     * @return
//     * @throws NoSuchAlgorithmException
//     * @throws UnsupportedEncodingException
//     */
//    private String createAuthHashInfo(final HttpServletRequest request, final String merchantCcId,
//            final String merchantPw, final String algorithmName, final String charset)
//            throws NoSuchAlgorithmException, UnsupportedEncodingException {
//
//        // ハッシュ値算出パラメータ順序の取得
//        String authParams = request.getParameter("authParams");
//
//        // ハッシュ値算出パラメータ順序のデコード
//        if (authParams == null) {
//            return null;
//        }
//        byte[] bytesBase64 = Base64.decodeBase64(authParams.getBytes(DEFAULT_CHARSET));
//        String[] paramOrder = new String(bytesBase64, DEFAULT_CHARSET).split(",", 0);
//
//        // パラメータ順序順にパラメータを取得し、連結させる。
//        StringBuffer params = new StringBuffer();
//        params.append(merchantCcId);
//        for (int i = 0; i < paramOrder.length; i++) {
//            params.append(request.getParameter(paramOrder[i]));
//        }
//        params.append(merchantPw);
//
//        // 連結したパラメータ値から指定されたアルゴリズムのダイジェストを生成
//        MessageDigest md = MessageDigest.getInstance(algorithmName);
//        md.update(params.toString().getBytes(charset));
//        // ダイジェスト値をバイト型で取得
//        byte[] hashBytes = md.digest();
//
//        // ハッシュ値用ビルダ
//        StringBuffer sbHash = new StringBuffer();
//        for (int i = 0; i < hashBytes.length; i++) {
//            byte b = hashBytes[i];
//            // 余分なオブジェクトを作らずに済むように、16進数文字をchar型で追記していく
//            // 上位4ビット（右から5～8ビット以外をすべて0クリア、4ビット右にずらす）
//            appendHalfByte(sbHash, (b & 0xf0) >> 4);
//            // 下位4ビット（下位4ビット以外をすべて0クリア）
//            appendHalfByte(sbHash, b & 0x0f);
//        }
//
//        return sbHash.toString();
//    }
//
//    private static void appendHalfByte(final StringBuffer sb, final int half) {
//        if (half < 10) {
//            // 0～9 は、'0' ～ '9'
//            sb.append((char)('0' + half));
//        } else {
//            // 10～15 は、'a' ～ 'f'
//            sb.append((char)('a' + (half - 10)));
//        }
//    }
}
