package jp.veritrans.tercerog.sample.web.saison.base;

import java.io.IOException;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.SaisonCaptureRequestDto;
import jp.veritrans.tercerog.mdk.dto.SaisonCaptureResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * クレディセゾン決済 売上処理クラス。
 */
public abstract class AbstractCaptureExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    abstract protected String getJsp();
    abstract protected String getJspResult();
    abstract protected void setCharacterEncoding(HttpServletRequest request) throws UnsupportedEncodingException;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        // 文字コードの指定
        setCharacterEncoding(request);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = request.getParameter("orderId");
        // 合計決済金額
        String amount = request.getParameter("amount");
        // 永久不滅ウォレット決済金額
        String walletAmount = request.getParameter("walletAmount");
        // カード決済金額
        String cardAmount = request.getParameter("cardAmount");
        // トークン
        String token = request.getParameter("token");
        // カード取引ＩＤ
        String cardOrderId = request.getParameter("cardOrderId");
        // カード売上フラグ
        String withCapture = request.getParameter("withCapture");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：合計決済金額が指定されていません</b></font>";
        } else if (isNull(walletAmount)) {
            warning =  "<font color='#ff0000'><b>必須項目：永久不滅ウォレット決済金額が指定されていません</b></font>";
        } else if (!isNum(amount)) {
            warning =  "<font color='#ff0000'><b>合計決済金額は数値で入力しなければなりません</b></font>";
        } else if (!isNum(walletAmount)) {
            warning =  "<font color='#ff0000'><b>永久不滅ウォレット決済金額は数値で入力しなければなりません</b></font>";
        } else if (!isNum(cardAmount)) {
            warning =  "<font color='#ff0000'><b>カード決済金額は数値で入力しなければなりません</b></font>";
        }

        int _amount = 0;
        int _walletAmount = 0;
        int _cardAmount = 0;
        if (isNull(warning)) {
            _amount = Integer.parseInt(amount);
            _walletAmount = Integer.parseInt(walletAmount);
            _cardAmount = 0;

            if (!isNull(cardAmount) && isNum(cardAmount)) {
                _cardAmount = Integer.parseInt(cardAmount);
            }
            if (_amount != (_walletAmount + _cardAmount)) {
                warning =  "<font color='#ff0000'><b>永久不滅ウォレット決済金額とカード決済金額の合計額が合計決済金額になる必要があります</b></font>";
            }
        }


        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, getJsp());
            return;
        }


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        SaisonCaptureRequestDto reqDto = new SaisonCaptureRequestDto();

        // オーダーIDの設定
        reqDto.setOrderId(orderId);
        // 合計決済金額の設定
        reqDto.setAmount(amount);
        // 永久不滅ウォレット決済金額の設定
        reqDto.setWalletAmount(walletAmount);
        // カード決済金額の設定
        reqDto.setCardAmount(cardAmount);
        // カード取引IDの設定
        reqDto.setCardOrderId(cardOrderId);
        // カード売上フラグ
        reqDto.setWithCapture(withCapture);
        // 合計決済金額と永久不滅ウォレット決済金額が等しくなければ、トークンを設定
        if (amount != walletAmount) {
            reqDto.setToken(token);
        }


        request.setAttribute("processName", "売上");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // コマンドを実行し、応答DTOを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        ITransaction tran = TransactionFactory.getInstance(reqDto);
        SaisonCaptureResponseDto resDto = (SaisonCaptureResponseDto) tran.execute();

        // 永久不滅ポイント処理結果の格納
        request.setAttribute("orderId", resDto.getOrderId());
        request.setAttribute("mStatus", resDto.getMstatus());
        request.setAttribute("mErrMsg", resDto.getMerrMsg());
        request.setAttribute("vResultCode", resDto.getVResultCode());

        // カード処理結果の格納
        request.setAttribute("cardOrderId", resDto.getCardOrderId());
        request.setAttribute("cardMStatus", resDto.getCardMstatus());
        request.setAttribute("cardMErrMsg", resDto.getCardMerrMsg());
        request.setAttribute("cardVResultCode", resDto.getCardVResultCode());
        request.setAttribute("reqCardNumber", resDto.getReqCardNumber());
        request.setAttribute("resAuthCode", resDto.getResAuthCode());

        forward(request, response, getJspResult());
    }

    /**
     * 文字列が数値であることをチェック。
     * @param num 検査する文字列
     * @return 数値の場合はtrue
     */
    private boolean isNum(String num) {
        if (num == null || num.length() == 0) {
            return true;
        }
        try {
            Integer.parseInt(num);
        } catch (NumberFormatException e) {
            return false;
        }
        return true;
    }

}
