package jp.veritrans.tercerog.sample.web.search;

import java.io.IOException;
import java.util.Arrays;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AlipaySearchParameter;
import jp.veritrans.tercerog.mdk.dto.AmazonpaySearchParameter;
import jp.veritrans.tercerog.mdk.dto.BankSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CardSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CarrierSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CommonSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CvsSearchParameter;
import jp.veritrans.tercerog.mdk.dto.EmSearchParameter;
import jp.veritrans.tercerog.mdk.dto.MpiSearchParameter;
import jp.veritrans.tercerog.mdk.dto.OrderInfo;
import jp.veritrans.tercerog.mdk.dto.OrderInfos;
import jp.veritrans.tercerog.mdk.dto.OricoscSearchParameter;
import jp.veritrans.tercerog.mdk.dto.PaypalSearchParameter;
import jp.veritrans.tercerog.mdk.dto.PaypaySearchParameter;
import jp.veritrans.tercerog.mdk.dto.RakutenSearchParameter;
import jp.veritrans.tercerog.mdk.dto.RecruitSearchParameter;
import jp.veritrans.tercerog.mdk.dto.LinepaySearchParameter;
import jp.veritrans.tercerog.mdk.dto.MasterpassSearchParameter;
import jp.veritrans.tercerog.mdk.dto.SaisonSearchParameter;
import jp.veritrans.tercerog.mdk.dto.SearchParameters;
import jp.veritrans.tercerog.mdk.dto.SearchRange;
import jp.veritrans.tercerog.mdk.dto.SearchRequestDto;
import jp.veritrans.tercerog.mdk.dto.SearchResponseDto;
import jp.veritrans.tercerog.mdk.dto.UpopSearchParameter;
import jp.veritrans.tercerog.mdk.dto.VirtualaccSearchParameter;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 共通検索サーブレット
 */
public class SearchExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // リクエストID
        String requestId = getParameter(request, "requestId");
        // 決済サービスタイプ
        String[] serviceTypeCd = request.getParameterValues("serviceTypeCd[]");
        // 取引ID
        String orderId = getParameter(request, "orderId");
        // コマンド
        String[] command = request.getParameterValues("command[]");
        // ステータスコード
        String[] mstatus = request.getParameterValues("mstatus[]");
        // オーダー決済状態
        String[] orderStatus = request.getParameterValues("orderStatus[]");
        // 取引日時 From
        String txnDatatimeFrom = getParameter(request, "txnDatatimeFrom");
        // 取引日時 To
        String txnDatatimeTo = getParameter(request, "txnDatatimeTo");
        // 金額 From
        String amountFrom = getParameter(request, "amountFrom");
        // 金額 To
        String amountTo = getParameter(request, "amountTo");
        // 最新トランザクションのみ
        String isNewerTxn = getParameter(request, "isNewerTxn");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 画面パラメータから新しいパラメータの型を生成します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引日時の範囲指定パラメータを生成します。
        SearchRange txnDatatimeRange = new SearchRange();
        txnDatatimeRange.setFrom(txnDatatimeFrom);
        txnDatatimeRange.setTo(txnDatatimeTo);
        // 金額の範囲指定パラメータを生成します。
        SearchRange amountRange = new SearchRange();
        amountRange.setFrom(amountFrom);
        amountRange.setTo(amountTo);


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // Commonパラメータクラスへのセット
        CommonSearchParameter common_param = new CommonSearchParameter();
        common_param.setOrderId(orderId);
        common_param.setCommand(command);
        common_param.setMstatus(mstatus);
        common_param.setOrderStatus(orderStatus);
        common_param.setTxnDatetime(txnDatatimeRange);
        common_param.setAmount(amountRange);

        // Searchパラメータクラスへのセット
        SearchParameters search_param = new SearchParameters();
        search_param.setCommon(common_param);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // サービス固有項目のパラメータを設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // ========================================
        // クレジットカード
        // ========================================
        if (checkService(serviceTypeCd, "card")) {
            // サービス固有項目の画面パラメータを取得
            String card_dddTransactionId           = getParameter(request, "card_dddTransactionId");           // 3d-xid

            // 設定
            CardSearchParameter card_param = new CardSearchParameter();
            card_param.setDddTransactionId(card_dddTransactionId);

            // 検索パラメータに設定
            search_param.setCard(card_param);
        }
        // ========================================
        // クレジットカード（本人認証）
        // ========================================
        if (checkService(serviceTypeCd, "mpi")) {
            // サービス固有項目の画面パラメータを取得
            String[] mpi_detailOrderType         = request.getParameterValues("mpi_detailOrderType[]");         // 詳細取引決済状態
            String mpi_res3dTransactionId        = getParameter(request, "mpi_res3dTransactionId");             // 応答3DトランザクションID
            String mpi_res3dTransactionStatus    = getParameter(request, "mpi_res3dTransactionStatus");         // 応答3Dトランザクションステータス
            String mpi_res3dEci                  = getParameter(request, "mpi_res3dEci");                       // 応答3D ECI
            String[] mpi_deviceChannel           = request.getParameterValues("mpi_deviceChannel[]");           // デバイスチャネル
            String[] mpi_accountType             = request.getParameterValues("mpi_accountType[]");             // アカウントタイプ

            // 設定
            MpiSearchParameter mpi_param = new MpiSearchParameter();
            mpi_param.setDetailOrderType(mpi_detailOrderType);
            mpi_param.setRes3dTransactionId(mpi_res3dTransactionId);
            mpi_param.setRes3dTransactionStatus(mpi_res3dTransactionStatus);
            mpi_param.setRes3dEci(mpi_res3dEci);
            mpi_param.setDeviceChannel(mpi_deviceChannel);
            mpi_param.setAccountType(mpi_accountType);

            // 検索パラメータに設定
            search_param.setMpi(mpi_param);
        }
        // ========================================
        // 電子マネー
        // ========================================
        if (checkService(serviceTypeCd, "em")) {
            // サービス固有項目の画面パラメータを取得
            String[] em_emType               = request.getParameterValues("em_emType[]");         // 電子マネー種別
            String   em_settlementLimitFrom  = getParameter(request, "em_settlementLimitFrom");  // 支払/受取期限 From
            String   em_settlementLimitTo    = getParameter(request, "em_settlementLimitTo");    // 支払/受取期限 To
            String   em_completeDatetimeFrom = getParameter(request, "em_completeDatetimeFrom"); // 支払完了日時 From
            String   em_completeDatetimeTo   = getParameter(request, "em_completeDatetimeTo");   // 支払完了日時 To
            String   em_receiptNo            = getParameter(request, "em_receiptNo");            // 受付番号

            // 支払/受取期限の範囲指定パラメータを生成
            SearchRange em_settlementLimitRange = new SearchRange();
            em_settlementLimitRange.setFrom(em_settlementLimitFrom);
            em_settlementLimitRange.setTo(em_settlementLimitTo);
            // 支払完了日時の範囲指定パラメータを生成
            SearchRange em_completeDatetimeRange = new SearchRange();
            em_completeDatetimeRange.setFrom(em_completeDatetimeFrom);
            em_completeDatetimeRange.setTo(em_completeDatetimeTo);

            // 設定
            EmSearchParameter em_param = new EmSearchParameter();
            em_param.setEmType(em_emType);
            em_param.setSettlementLimit(em_settlementLimitRange);
            em_param.setCompleteDatetime(em_completeDatetimeRange);
            em_param.setReceiptNo(em_receiptNo);

            // 検索パラメータに設定
            search_param.setEm(em_param);
        }
        // ========================================
        // コンビニ
        // ========================================
        if (checkService(serviceTypeCd, "cvs")) {
        // サービス固有項目の画面パラメータを取得
            String[] cvs_cvsType          = request.getParameterValues("cvs_cvsType[]");               // コンビニタイプ
            String   cvs_payLimitFrom     = getParameter(request, "cvs_payLimitFrom");                 // 支払期限 From
            String   cvs_payLimitTo       = getParameter(request, "cvs_payLimitTo");                   // 支払期限 To
            String   cvs_payLimitDatetimeFrom = getParameter(request, "cvs_payLimitDatetimeFrom");     // 支払期限日時 From
            String   cvs_payLimitDatetimeTo   = getParameter(request, "cvs_payLimitDatetimeTo");       // 支払期限日時 To
            String   cvs_paidDatetimeFrom = getParameter(request, "cvs_paidDatetimeFrom");             // 入金受付日 From
            String   cvs_paidDatetimeTo   = getParameter(request, "cvs_paidDatetimeTo");               // 入金受付日 To

            // 支払期限の範囲指定パラメータを生成
            SearchRange cvs_payLimitRange = new SearchRange();
            cvs_payLimitRange.setFrom(cvs_payLimitFrom);
            cvs_payLimitRange.setTo(cvs_payLimitTo);
            // 支払期限日時の範囲指定パラメータを生成
            SearchRange cvs_payLimitDatetimeRange = new SearchRange();
            cvs_payLimitDatetimeRange.setFrom(cvs_payLimitDatetimeFrom);
            cvs_payLimitDatetimeRange.setTo(cvs_payLimitDatetimeTo);
            // 入金受付日の範囲指定パラメータを生成
            SearchRange cvs_paidDatetimeRange = new SearchRange();
            cvs_paidDatetimeRange.setFrom(cvs_paidDatetimeFrom);
            cvs_paidDatetimeRange.setTo(cvs_paidDatetimeTo);

            // 設定
            CvsSearchParameter cvs_param = new CvsSearchParameter();
            cvs_param.setCvsType(cvs_cvsType);
            cvs_param.setPayLimit(cvs_payLimitRange);
            cvs_param.setPayLimitDatetime(cvs_payLimitDatetimeRange);
            cvs_param.setPaidDatetime(cvs_paidDatetimeRange);

            // 検索パラメータに設定
            search_param.setCvs(cvs_param);
        }
        // ========================================
        // 銀行
        // ========================================
        if (checkService(serviceTypeCd, "bank")) {
            // サービス固有項目の画面パラメータを取得
            String bank_payLimitFrom         = getParameter(request, "bank_payLimitFrom");         // 支払期限 From
            String bank_payLimitTo           = getParameter(request, "bank_payLimitTo");           // 支払期限 To
            String bank_receivedDatetimeFrom = getParameter(request, "bank_receivedDatetimeFrom"); // 収納日時 From
            String bank_receivedDatetimeTo   = getParameter(request, "bank_receivedDatetimeTo");   // 収納日時 To
            String bank_shunoKikanNo         = getParameter(request, "bank_shunoKikanNo");         // 収納機関番号
            String bank_shunoKigyoNo         = getParameter(request, "bank_shunoKigyoNo");         // 収納企業コード
            String bank_customerNo           = getParameter(request, "bank_customerNo");           // お客様番号
            String bank_confirmNo            = getParameter(request, "bank_confirmNo");            // 確認番号

            // 支払期限の範囲指定パラメータを生成
            SearchRange bank_payLimitRange = new SearchRange();
            bank_payLimitRange.setFrom(bank_payLimitFrom);
            bank_payLimitRange.setTo(bank_payLimitTo);
            // 収納日時の範囲指定パラメータを生成
            SearchRange bank_receivedDatetimeRange = new SearchRange();
            bank_receivedDatetimeRange.setFrom(bank_receivedDatetimeFrom);
            bank_receivedDatetimeRange.setTo(bank_receivedDatetimeTo);

            // 設定
            BankSearchParameter bank_param = new BankSearchParameter();
            bank_param.setPayLimit(bank_payLimitRange);
            bank_param.setReceivedDatetime(bank_receivedDatetimeRange);
            bank_param.setShunoKikanNo(bank_shunoKikanNo);
            bank_param.setShunoKigyoNo(bank_shunoKigyoNo);
            bank_param.setCustomerNo(bank_customerNo);
            bank_param.setConfirmNo(bank_confirmNo);

            // 検索パラメータに設定
            search_param.setBank(bank_param);
        }
        // ========================================
        // PayPal
        // ========================================
        if (checkService(serviceTypeCd, "paypal")) {
            // サービス固有項目の画面パラメータを取得
            String paypal_paymentDatetimeFrom = getParameter(request, "paypal_paymentDatetimeFrom"); // 支払日時 From
            String paypal_paymentDatetimeTo   = getParameter(request, "paypal_paymentDatetimeTo");   // 支払日時 To
            String paypal_invoiceId           = getParameter(request, "paypal_invoiceId");           // 請求番号
            String paypal_payerId             = getParameter(request, "paypal_payerId");             // 顧客番号

            // 支払日時の範囲指定パラメータを生成
            SearchRange paypal_paymentDatetimeRange = new SearchRange();
            paypal_paymentDatetimeRange.setFrom(paypal_paymentDatetimeFrom);
            paypal_paymentDatetimeRange.setTo(paypal_paymentDatetimeTo);

            // 設定
            PaypalSearchParameter paypal_param = new PaypalSearchParameter();
            paypal_param.setPaymentDatetime(paypal_paymentDatetimeRange);
            paypal_param.setInvoiceId(paypal_invoiceId);
            paypal_param.setPayerId(paypal_payerId);

            // 検索パラメータに設定
            search_param.setPaypal(paypal_param);
        }
        // ========================================
        // Saison
        // ========================================
        if (checkService(serviceTypeCd, "saison")) {
            // サービス固有項目の画面パラメータを取得
            String saison_totalAmountFrom  = getParameter(request, "saison_totalAmountFrom");  // 合計決済金額 From
            String saison_totalAmountTo    = getParameter(request, "saison_totalAmountTo");    // 合計決済金額 To
            String saison_walletAmountFrom = getParameter(request, "saison_walletAmountFrom"); // ウォレット決済金額 From
            String saison_walletAmountTo   = getParameter(request, "saison_walletAmountTo");   // ウォレット決済金額 To
            String saison_cardAmountFrom   = getParameter(request, "saison_cardAmountFrom");   // カード決済金額 From
            String saison_cardAmountTo     = getParameter(request, "saison_cardAmountTo");     // カード決済金額 To

            // 合計決済金額の範囲指定パラメータを生成
            SearchRange saison_totalAmountRange = new SearchRange();
            saison_totalAmountRange.setFrom(saison_totalAmountFrom);
            saison_totalAmountRange.setTo(saison_totalAmountTo);

            // ウォレット決済金額の範囲指定パラメータを生成
            SearchRange saison_walletAmountRange = new SearchRange();
            saison_walletAmountRange.setFrom(saison_walletAmountFrom);
            saison_walletAmountRange.setTo(saison_walletAmountTo);

            // カード決済金額の範囲指定パラメータを生成
            SearchRange saison_cardAmountRange = new SearchRange();
            saison_cardAmountRange.setFrom(saison_cardAmountFrom);
            saison_cardAmountRange.setTo(saison_cardAmountTo);

            // 設定
            SaisonSearchParameter saison_param = new SaisonSearchParameter();
            saison_param.setTotalAmount(saison_totalAmountRange);
            saison_param.setWalletAmount(saison_walletAmountRange);
            saison_param.setCardAmount(saison_cardAmountRange);

            // 検索パラメータに設定
            search_param.setSaison(saison_param);
        }
        // ========================================
        // UPOP
        // ========================================
        if (checkService(serviceTypeCd, "upop")) {
            // サービス固有項目の画面パラメータを取得
            String upop_settleDatetimeJpFrom = getParameter(request,
                    "upop_settleDatetimeJpFrom"); // 決済日時(日本) From
            String upop_settleDatetimeJpTo = getParameter(request,
                    "upop_settleDatetimeJpTo"); // 決済日時(日本) To
            String upop_settleDatetimeCnFrom = getParameter(request,
                    "upop_settleDatetimeCnFrom"); // 決済日時(中国) From
            String upop_settleDatetimeCnTo = getParameter(request,
                    "upop_settleDatetimeCnTo"); // 決済日時(中国) To

            String upop_detailOrderType[] = request
                    .getParameterValues("detailOrderType[]");

            // 決済日時(日本)の範囲指定パラメータを生成
            SearchRange upop_settleDatetimeJpRange = new SearchRange();
            upop_settleDatetimeJpRange.setFrom(upop_settleDatetimeJpFrom);
            upop_settleDatetimeJpRange.setTo(upop_settleDatetimeJpTo);

            // 決済日時(中国)の範囲指定パラメータを生成
            SearchRange upop_settleDatetimeCnRange = new SearchRange();
            upop_settleDatetimeCnRange.setFrom(upop_settleDatetimeCnFrom);
            upop_settleDatetimeCnRange.setTo(upop_settleDatetimeCnTo);

            // 設定
            UpopSearchParameter upop_param = new UpopSearchParameter();
            upop_param.setSettleDatetimeJp(upop_settleDatetimeJpRange);
            upop_param.setSettleDatetimeCn(upop_settleDatetimeCnRange);
            upop_param.setDetailOrderType(upop_detailOrderType);

            // 検索パラメータに設定
            search_param.setUpop(upop_param);

        }
        // ========================================
        // Alipay
        // ========================================
        if (checkService(serviceTypeCd, "alipay")) {
            // サービス固有項目の画面パラメータを取得
            String alipay_centerTradeId = getParameter(request,
                    "alipay_centerTradeId"); // 決済センターとの取引ID
            String alipay_paymentTimeFrom = getParameter(request,
                    "alipay_paymentTimeFrom"); // 支払い日時From
            String alipay_paymentTimeTo = getParameter(request,
                    "alipay_paymentTimeTo"); // 支払い日時 To
            String alipay_settlementTimeFrom = getParameter(request,
                    "alipay_settlementTimeFrom"); // 清算日時From
            String alipay_settlementTimeTo = getParameter(request,
                    "alipay_settlementTimeTo"); // 清算日時To

            String alipay_payType[] = request
                    .getParameterValues("alipay_payType[]");

            String alipay_detailOrderType[] = request
                    .getParameterValues("alipayDetailOrderType[]");

            // 支払い日時の範囲指定パラメータを生成
            SearchRange alipay_paymentTimeRange = new SearchRange();
            alipay_paymentTimeRange.setFrom(alipay_paymentTimeFrom);
            alipay_paymentTimeRange.setTo(alipay_paymentTimeTo);

            // 清算日時の範囲指定パラメータを生成
            SearchRange alipay_settlementTimeRange = new SearchRange();
            alipay_settlementTimeRange.setFrom(alipay_settlementTimeFrom);
            alipay_settlementTimeRange.setTo(alipay_settlementTimeTo);

            // 設定
            AlipaySearchParameter alipay_param = new AlipaySearchParameter();
            alipay_param.setCenterTradeId(alipay_centerTradeId);
            alipay_param.setPaymentTime(alipay_paymentTimeRange);
            alipay_param.setSettlementTime(alipay_settlementTimeRange);
            alipay_param.setDetailOrderType(alipay_detailOrderType);
            alipay_param.setPayType(alipay_payType);

            // 検索パラメータに設定
            search_param.setAlipay(alipay_param);

        }

        // ========================================
        // キャリア
        // ========================================
        if (checkService(serviceTypeCd, "carrier")) {
            // サービス固有項目の画面パラメータを取得
            String[] carrier_detailOrderType = request.getParameterValues("carrier_detailOrderType[]"); // 詳細オーダー決済状態
            String[] carrier_crServiceType = request.getParameterValues("carrier_crServiceType[]"); // キャリアサービスタイプ
            String carrier_accountingType = getParameter(request, "carrier_accountingType"); // 課金種別
            String[] carrier_itemType = request.getParameterValues("carrier_itemType[]"); // 商品タイプ
            String[] carrier_mpStatus = request.getParameterValues("carrier_mpStatus[]"); // 継続状態フラグ
            String[] carrier_terminalKind = request.getParameterValues("carrier_terminalKind[]"); // 端末種別
            String[] carrier_detailCommandType = request.getParameterValues("carrier_detailCommandType[]"); // 詳細コマンドタイプ
            String carrier_mpFirstDate = getParameter(request, "carrier_mpFirstDate"); // 初回課金年月日
            String carrier_mpDay = getParameter(request, "carrier_mpDay"); // 継続課金日
            String carrier_itemId = getParameter(request, "carrier_itemId"); // 商品番号

            // 設定
            CarrierSearchParameter carrier_param = new CarrierSearchParameter();
            carrier_param.setDetailOrderType(carrier_detailOrderType);
            carrier_param.setCrServiceType(carrier_crServiceType);
            carrier_param.setAccountingType(carrier_accountingType);
            carrier_param.setItemType(carrier_itemType);
            carrier_param.setMpStatus(carrier_mpStatus);
            carrier_param.setTerminalKind(carrier_terminalKind);
            carrier_param.setDetailCommandType(carrier_detailCommandType);
            carrier_param.setMpFirstDate(carrier_mpFirstDate);
            carrier_param.setMpDay(carrier_mpDay);
            carrier_param.setItemId(carrier_itemId);

            // 検索パラメータに設定
            search_param.setCarrier(carrier_param);

        }

        // ========================================
        // ショッピングクレジット
        // ========================================
        if (checkService(serviceTypeCd, "oricosc")) {
            // サービス固有項目の画面パラメータを取得
            String oricosc_oricoOrderNo  = getParameter(request, "oricosc_oricoOrderNo");                  // 注文番号
            String oricosc_amountFrom    = getParameter(request, "oricosc_amountFrom");                    // 支払合計金額 From
            String oricosc_amountTo   = getParameter(request, "oricosc_amountTo");                         // 支払合計金額 To
            String oricosc_totalItemAmountFrom   = getParameter(request, "oricosc_totalItemAmountFrom");   // 商品価格合計(税込) From
            String oricosc_totalItemAmountTo     = getParameter(request, "oricosc_totalItemAmountTo");     // 商品価格合計(税込) To

            // 支払合計金額の範囲指定パラメータを生成
            SearchRange oricosc_amountRange = new SearchRange();
            oricosc_amountRange.setFrom(oricosc_amountFrom);
            oricosc_amountRange.setTo(oricosc_amountTo);

            // 商品価格合計(税込)の範囲指定パラメータを生成
            SearchRange oricosc_totalItemAmountRange = new SearchRange();
            oricosc_totalItemAmountRange.setFrom(oricosc_totalItemAmountFrom);
            oricosc_totalItemAmountRange.setTo(oricosc_totalItemAmountTo);

            // 設定
            OricoscSearchParameter oricosc_param = new OricoscSearchParameter();
            oricosc_param.setOricoOrderNo(oricosc_oricoOrderNo);
            oricosc_param.setAmount(oricosc_amountRange);
            oricosc_param.setTotalItemAmount(oricosc_totalItemAmountRange);

            // 検索パラメータに設定
            search_param.setOricosc(oricosc_param);
        }

        // ========================================
        // 楽天
        // ========================================
        if (checkService(serviceTypeCd, "rakuten")) {
            // サービス固有項目の画面パラメータを取得
            String[] rakuten_detailOrderType = request.getParameterValues("rakuten_detailOrderType[]"); // 詳細オーダー決済状態
            String[] rakuten_detailCommandType = request.getParameterValues("rakuten_detailCommandType[]"); // 詳細コマンドタイプ
            String rakuten_itemId = getParameter(request, "rakuten_itemId"); // 商品番号
            String[] rakuten_payType = request.getParameterValues("rakuten_payType[]"); // 決済種別
            String rakuten_accountingType = getParameter(request, "rakuten_accountingType"); // 課金種別
            String[] rakuten_consentStatus = request.getParameterValues("rakuten_consentStatus[]"); // 承諾状態
            String rakuten_originalOrderId = getParameter(request, "rakuten_originalOrderId"); // 元取引ID

            // 設定
            RakutenSearchParameter rakuten_param = new RakutenSearchParameter();
            rakuten_param.setDetailOrderType(rakuten_detailOrderType);
            rakuten_param.setDetailCommandType(rakuten_detailCommandType);
            rakuten_param.setItemId(rakuten_itemId);
            rakuten_param.setPayType(rakuten_payType);
            rakuten_param.setAccountingType(rakuten_accountingType);
            rakuten_param.setConsentStatus(rakuten_consentStatus);
            rakuten_param.setOriginalOrderId(rakuten_originalOrderId);

            // 検索パラメータに設定
            search_param.setRakuten(rakuten_param);
        }

        // ========================================
        // リクルート
        // ========================================
        if (checkService(serviceTypeCd, "recruit")) {
            // サービス固有項目の画面パラメータを取得
            String[] recruit_detailOrderType = request.getParameterValues("recruit_detailOrderType[]"); // 詳細オーダー決済状態
            String[] recruit_detailCommandType = request.getParameterValues("recruit_detailCommandType[]"); // 詳細コマンドタイプ
            String recruit_itemId = getParameter(request, "recruit_itemId"); // 商品番号

            // 設定
            RecruitSearchParameter recruit_param = new RecruitSearchParameter();
            recruit_param.setDetailOrderType(recruit_detailOrderType);
            recruit_param.setDetailCommandType(recruit_detailCommandType);
            recruit_param.setItemId(recruit_itemId);

            // 検索パラメータに設定
            search_param.setRecruit(recruit_param);
        }

        // ========================================
        // LINE Pay
        // ========================================
        if (checkService(serviceTypeCd, "linepay")) {
            // サービス固有項目の画面パラメータを取得
            String[] linepay_detailOrderType = request.getParameterValues("linepay_detailOrderType[]"); // 詳細オーダー決済状態
            String[] linepay_detailCommandType = request.getParameterValues("linepay_detailCommandType[]"); // 詳細コマンドタイプ
            String linepay_itemId = getParameter(request, "linepay_itemId"); // 商品番号

            // 設定
            LinepaySearchParameter linepay_param = new LinepaySearchParameter();
            linepay_param.setDetailOrderType(linepay_detailOrderType);
            linepay_param.setDetailCommandType(linepay_detailCommandType);
            linepay_param.setItemId(linepay_itemId);

            // 検索パラメータに設定
            search_param.setLinepay(linepay_param);
        }


        // ========================================
        // MasterPass
        // ========================================
        if (checkService(serviceTypeCd, "masterpass")) {
            // サービス固有項目の画面パラメータを取得
            String[] masterpass_detailOrderType = request.getParameterValues("masterpass_detailOrderType[]"); // 詳細オーダー決済状態
            String[] masterpass_detailCommandType = request.getParameterValues("masterpass_detailCommandType[]"); // 詳細コマンドタイプ
            String masterpass_itemId = getParameter(request, "masterpass_itemId"); // 商品番号
            String masterpass_acquirerCode = getParameter(request, "masterpass_acquirerCode"); // 仕向け先コード

            // 設定
            MasterpassSearchParameter masterpass_param = new MasterpassSearchParameter();
            masterpass_param.setDetailOrderType(masterpass_detailOrderType);
            masterpass_param.setDetailCommandType(masterpass_detailCommandType);
            masterpass_param.setItemId(masterpass_itemId);
            masterpass_param.setAcquirerCode(masterpass_acquirerCode);

            // 検索パラメータに設定
            search_param.setMasterpass(masterpass_param);
        }

        // ========================================
        // 銀行振込
        // ========================================
        if (checkService(serviceTypeCd, "virtualacc")) {
            // サービス固有項目の画面パラメータを取得
            String[] virtualacc_detailOrderType = request.getParameterValues("virtualacc_detailOrderType[]"); // 詳細オーダー決済状態
            String[] virtualacc_detailCommandType = request.getParameterValues("virtualacc_detailCommandType[]"); // 詳細コマンドタイプ
            String virtualacc_entryTransferName = getParameter(request, "virtualacc_entryTransferName"); // 登録時振込人名
            String virtualacc_entryTransferNumber = getParameter(request, "virtualacc_entryTransferNumber"); // 登録時振込番号
            String virtualacc_accountNumber = getParameter(request, "virtualacc_accountNumber"); // 口座番号

            // 設定
            VirtualaccSearchParameter virtualacc_param = new VirtualaccSearchParameter();
            virtualacc_param.setDetailOrderType(virtualacc_detailOrderType);
            virtualacc_param.setDetailCommandType(virtualacc_detailCommandType);
            virtualacc_param.setEntryTransferName(virtualacc_entryTransferName);
            virtualacc_param.setEntryTransferNumber(virtualacc_entryTransferNumber);
            virtualacc_param.setAccountNumber(virtualacc_accountNumber);

            // 検索パラメータに設定
            search_param.setVirtualacc(virtualacc_param);
        }

        // ========================================
        // PayPay
        // ========================================
        if (checkService(serviceTypeCd, "paypay")) {
            // サービス固有項目の画面パラメータを取得
            String[] paypay_detailOrderType = request.getParameterValues("paypay_detailOrderType[]"); // 詳細オーダー決済状態
            String[] paypay_detailCommandType = request.getParameterValues("paypay_detailCommandType[]"); // 詳細コマンドタイプ
            String[] paypay_paypayServiceType = request.getParameterValues("paypay_paypayServiceType[]"); // PayPayサービスタイプ

            // 設定
            PaypaySearchParameter paypay_param = new PaypaySearchParameter();
            paypay_param.setDetailOrderType(paypay_detailOrderType);
            paypay_param.setDetailCommandType(paypay_detailCommandType);
            paypay_param.setPaypayServiceType(paypay_paypayServiceType);

            // 検索パラメータに設定
            search_param.setPaypay(paypay_param);
        }

        // ========================================
        // AmazonPay
        // ========================================
        if (checkService(serviceTypeCd, "amazonpay")) {
            // サービス固有項目の画面パラメータを取得
            String[] amazonpay_detailOrderType = request.getParameterValues("amazonpay_detailOrderType[]"); // 詳細オーダー決済状態
            String[] amazonpay_detailCommandType = request.getParameterValues("amazonpay_detailCommandType[]"); // 詳細コマンドタイプ
            String amazonpay_centerOrderId = getParameter(request, "amazonpay_centerOrderId"); // 決済センターの管理ID
            String amazonpay_centerTransactionId = getParameter(request, "amazonpay_centerTransactionId"); // 決済センターのトランザクション管理ID
            String amazonpay_payConfirmScreenType = getParameter(request, "amazonpay_payConfirmScreenType"); // 決済確認画面種別

            // 設定
            AmazonpaySearchParameter amazonpay_param = new AmazonpaySearchParameter();
            amazonpay_param.setDetailOrderType(amazonpay_detailOrderType);
            amazonpay_param.setDetailCommandType(amazonpay_detailCommandType);
            amazonpay_param.setCenterOrderId(amazonpay_centerOrderId);
            amazonpay_param.setCenterTransactionId(amazonpay_centerTransactionId);
            amazonpay_param.setPayConfirmScreenType(amazonpay_payConfirmScreenType);

            // 検索パラメータに設定
            search_param.setAmazonpay(amazonpay_param);
        }

        // 検索DTOへパラメータクラスをセット
        SearchRequestDto request_data = new SearchRequestDto();
        request_data.setRequestId(requestId);                  // リクエストID
        if (isNewerTxn != null && isNewerTxn.equals("true")) {
            request_data.setNewerFlag("true");                 // 商品に紐付く最後の取引のみ対象にするかを示す
        } else {
            request_data.setNewerFlag("false");                // 商品に紐付く全ての取引のみ対象にするかを示す
        }
        request_data.setContainDummyFlag("1");                 // 検索対象にダミー決済のレコードを含めるかを示す
        request_data.setServiceTypeCd(serviceTypeCd);          // 検索対象のサービスタイプを示す
        request_data.setSearchParameters(search_param);        // 各機能の固有条件

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(request_data);
            SearchResponseDto response_data = (SearchResponseDto)transaction.execute();

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 結果画面に表示します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 処理結果メッセージを設定（View機能へ引き渡す）
            String warning = response_data.getMerrMsg();
            request.setAttribute("warning", warning);

            // 配列データを設定（View機能へ引き渡す）
            OrderInfos order_infos = response_data.getOrderInfos();
            if (order_infos != null) {
                OrderInfo[] order_info = order_infos.getOrderInfo();
                request.setAttribute("order_info", order_info);
            }

            // 結果画面を表示
            forward(request, response, "./SearchExec.jsp");
        } catch (Exception ex) {
            ex.printStackTrace();
            // トランザクションオブジェクトの生成失敗など、
            // Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./SearchExec.jsp");
            return;
        } finally {
        }
    }

    /**
     * HTTPパラメータを取得する。
     * ただし、空文字の場合はnullへ変換される。
     */
    private String getParameter(final HttpServletRequest request, final String key) {
        String value = request.getParameter(key);
        if ("".equals(value)) {
            return null;
        } else {
            return value;
        }
    }

    /**
     * 検索対象の決済サービスタイプであるかをチェックする。
     */
    private boolean checkService(final String[] serviceTypeCd, final String target) {
        if (serviceTypeCd == null) {
            return false;
        }
        return Arrays.asList(serviceTypeCd).contains(target);
    }
}
