package jp.veritrans.tercerog.sample.web.virtualacc;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.VirtualaccAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.VirtualaccAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 銀行振込決済処理クラス。
 */
public class AuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        request.setCharacterEncoding("UTF-8");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 登録時振込人名の取得
        String entryTransferName = request.getParameter("entryTransferName");
        // 口座振込番号の設定
        String entryTransferNumber = request.getParameter("entryTransferNumber");
        // 振込期限の設定
        String transferExpiredDate = request.getParameter("transferExpiredDate");
        // 口座管理方式の取得
        String accountManageType = request.getParameter("accountManageType");
        //支店コードの取得
        String branchCode = request.getParameter("branchCode");
        //口座番号の取得
        String accountNumber = request.getParameter("accountNumber");
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Authorize.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        VirtualaccAuthorizeRequestDto reqDto = new VirtualaccAuthorizeRequestDto();

        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // 口座振込人名の設定
        reqDto.setEntryTransferName(entryTransferName);
        // 口座振込番号の設定
        reqDto.setEntryTransferNumber(entryTransferNumber);
        // 振込期限の設定
        reqDto.setTransferExpiredDate(transferExpiredDate);
        // 口座管理方式の設定
        reqDto.setAccountManageType(accountManageType);
        // 支店コードの設定
        reqDto.setBranchCode(branchCode);
        // 口座番号の設定
        reqDto.setAccountNumber(accountNumber);
        // サービスオプションタイプの設定
        reqDto.setServiceOptionType(MdkServiceConstants.VACC_RESONA);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            VirtualaccAuthorizeResponseDto resDto = (VirtualaccAuthorizeResponseDto)tran.execute();
            // 結果画面を表示します
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("transferName", resDto.getTransferName());
            request.setAttribute("bankName", resDto.getBankName());
            request.setAttribute("bankCode", resDto.getBankCode());
            request.setAttribute("branchName", resDto.getBranchName());
            request.setAttribute("branchCode", resDto.getBranchCode());
            request.setAttribute("accountType", resDto.getAccountType());
            request.setAttribute("accountNumber", resDto.getAccountNumber());
            request.setAttribute("accountName", resDto.getAccountName());
            forward(request, response, "./AuthorizeExec.jsp");
        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./AuthorizeExec.jsp");
        }
    }
}
