package jp.veritrans.tercerog.sample.web.virtualacc;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.mdk.dto.VirtualaccDepositEntryRequestDto;
import jp.veritrans.tercerog.mdk.dto.VirtualaccDepositEntryResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 銀行振込決済入金請求処理クラス。
 */
public class DepositEntryExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        request.setCharacterEncoding("UTF-8");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");
        // 金額の取得
        String amount = request.getParameter("amount");
        // 振込人名の設定
        String transferName = request.getParameter("transferName");
        // 消込フラグの設定
        String withReconcile = request.getParameter("withReconcile");
        // 登録方法の設定
        String registrationMethod = request.getParameter("registrationMethod");
        // 入金日の取得
        String depositDate = request.getParameter("depositDate");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./DepositEntry.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        VirtualaccDepositEntryRequestDto reqDto = new VirtualaccDepositEntryRequestDto();

        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // 振込人名の設定
        reqDto.setTransferName(transferName);
        // 消込フラグの設定
        reqDto.setWithReconcile(withReconcile);
        // 登録方法の設定
        reqDto.setRegistrationMethod(registrationMethod);
        // 入金日の設定
        reqDto.setDepositDate(depositDate);
        // サービスオプションタイプの設定
        reqDto.setServiceOptionType(MdkServiceConstants.VACC_RESONA);

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            VirtualaccDepositEntryResponseDto resDto = (VirtualaccDepositEntryResponseDto)tran.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("totalDepositAmount", resDto.getTotalDepositAmount());
            request.setAttribute("depositId", resDto.getDepositId());
            request.setAttribute("orderStatus", resDto.getOrderStatus());

            // 結果画面を表示します
            forward(request, response, "./DepositEntryExec.jsp");

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./DepositEntryExec.jsp");
        }
    }

}
